@@ -42,7 +42,7 @@ Expert1(void)
     printf("    theseus %s-a0 -e2 -g1 -i200 -k-1 -L0 -p1e-7 -v -P0%s your.pdb               \n", tc_GREEN, tc_NC);
     printf("\n");
     printf(" Expert options:\n");
-    //printf("    -b  Bayesian reference prior on inverse gamma scale param                   \n");
+    printf("    -b  Bayesian reference prior on inverse gamma scale param                   \n");
     printf("    -e  embedding algorithm for initializing the average structure              \n");
     printf("          0 = none; use randomly chosen model                                   \n");
     printf("         {%s2%s} = Maximum Likelihood                                           \n", tc_GREEN, tc_NC);
