@@ -29,6 +29,6 @@
 #include "pdbMalloc.h"
 
 void
-FragDist(CoordsArray *cdsA, int fraglen, int center_ca);
+FragDist(CdsArray *cdsA, int fraglen, int center_ca);
 
 #endif
