@@ -41,6 +41,10 @@
 #include "distfit.h"
 #include "DLTmath.h"
 #include "RandCds.h"
+#include "ProcGSLSVD.h"
+#include "DLTmath.h"
+#include "libdistfit/vonmises_dist.h"
+#include <gsl/gsl_math.h>
 #include <gsl/gsl_sf_hyperg.h>
 #include <gsl/gsl_rng.h>
 #include <gsl/gsl_randist.h>
@@ -420,7 +424,13 @@ scale_met3(const double n, const double gamma, const double phi, const double x,
 static double 
 scale_log_target_ratio(const double n, const double gamma, const double phi, const double x, const double y)
 {
-    return(-0.5*phi*(y*y - x*x) + gamma*(y-x) + (n-1.0) * log(y/x));
+    double k = 2.0;
+    double theta = 1.0/2.0;
+    double hngamma = -0.5*phi*(y*y - x*x) + gamma*(y-x) + (n-1.0) * log(y/x);
+    //hngamma = 0.0;
+    double prior = (k-1.0) * log(y/x) - (y-x)/theta; // gamma prior
+    
+    return(hngamma + prior);
 }
 
 
@@ -429,28 +439,33 @@ scale_log_met3(const double n, const double gamma, const double phi, double x, c
 {
     double          r, y, u;
     int             i;
+    double          jit;
 
     for (i = 0; i < iters; ++i)
     {
         //y = x + (2.0 * width * gsl_rng_uniform(r2) - width);
         //y = loc + gsl_ran_gaussian(r2, 3.0 * width);
-        y = x + gsl_ran_gaussian(r2, width);
+        jit = gsl_ran_gaussian(r2, 3.0 * width);
+        //y = x + gsl_ran_gaussian(r2, width);
+        //jit = gsl_rng_uniform(r2) * 0.6 - 0.3;
+        //jit = gsl_ran_gaussian(r2, 0.7);
+        y = x + jit;
 
         if (y < 0.0)
            y = -y;
         r = scale_log_target_ratio(n, gamma, phi, x, y);
         u = log(gsl_rng_uniform(r2));
 
-        //printf("\nMETROPOLIS: % e % e -- % f % f", x, y, r, u);
+        //printf("\nMETROPOLIS: % e % e -- % f % f % f", x, y, r, u, jit);
 
         if (u < r)
         {
-            //printf("\nACCEPT: 1");
+            //printf("\nACCEPT: 1 %e", y);
             x = y;
         }
         else
         {
-            //printf("\nACCEPT: 0");
+            //printf("\nACCEPT: 0 %e", x);
         }
     }
 
@@ -460,28 +475,29 @@ scale_log_met3(const double n, const double gamma, const double phi, double x, c
 
 /*
 KVM
-
 For simplicity of presentation take phi =1
-
 */
 double
-scale_rejection(const double n, const double gamma, const double phi, const gsl_rng *r2)
+scale_rejection(const double r, const double gamma, const double phi, const gsl_rng *r2)
 {
-    double          r, y, u, t;
+    double         sqrtphi = sqrt(phi);
+    double         g = gamma / sqrtphi;
+    double         R, y, u;
+    double         b = 0.5 * (g + sqrt(g*g + 4.0 * r));
 
     do
     {
         u = gsl_rng_uniform(r2);
-        y = gsl_ran_gamma(r2, n, 1.0);
-        t = y - gamma - 1.0;
-        r = exp(-0.5*t*t);
+        y = gsl_ran_gamma(r2, r, b - g);
+//        t = y - gamma - 1.0;
+        R = exp(-0.25 * g * g) * pow(b - g, -r) / CalcUax(r - 0.5, -g);
 
-        //printf("\nREJ: %e %e %e", u, y, r);
-        //fflush(NULL);
+        printf("\nREJ: %e %e %e", u, y, R);
+        fflush(NULL);
     }
-    while (u >= r);
+    while (u >= R);
 
-    return(y);
+    return(y/sqrtphi);
 }
 
 
@@ -564,12 +580,12 @@ MetScale(CdsArray *cdsA, const gsl_rng *r2)
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     const int       n = 3.0 * vlen + 1.0;
     double          phi, gamma;
-    Cds         *cdsi = NULL;
-    Cds         *avecds = cdsA->avecds;
+    Cds            *cdsi = NULL;
+    Cds            *avecds = cdsA->avecds;
     double          sm, width, oldscale;
     double          var = cdsA->stats->var;
     int             skip = 7;
-    double          priorg = 1.0;
+    double          priorg = 0.0;
 
     double sum = 0.0;
     for (i = 0; i < cnum; ++i)
@@ -597,8 +613,8 @@ MetScale(CdsArray *cdsA, const gsl_rng *r2)
         cdsi->scale = scale_log_met3(n, gamma, phi, oldscale, r2, sm, width, skip);
         ScaleCds(cdsi, cdsi->scale / oldscale);
 
-        printf("\nscale[%3d]: % f % f % f % f % f", i+1, cdsi->scale, phi, gamma, sm, width);
-        fflush(NULL);
+        //printf("\nscale[%3d]: % f % f % f % f % f", i+1, cdsi->scale, phi, gamma, sm, width);
+        //fflush(NULL);
     }
 }
 
@@ -610,12 +626,12 @@ MetScaleDiag(CdsArray *cdsA, const gsl_rng *r2)
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     const int       n = 3.0 * vlen + 1.0;
     double          phi, gamma;
-    Cds         *cdsi = NULL;
-    Cds         *avecds = cdsA->avecds;
+    Cds            *cdsi = NULL;
+    Cds            *avecds = cdsA->avecds;
     double         *wts = cdsA->w;
     double          sm, width, oldscale;
     int             skip = 7;
-    double          priorg = 1.0;
+    double          priorg = 0.0; // set to 1.0 for exponential prior mean = 1
 
     double sum = 0.0;
     for (i = 0; i < cnum; ++i)
@@ -648,10 +664,12 @@ MetScaleDiag(CdsArray *cdsA, const gsl_rng *r2)
 /*                cdsi->center[0], cdsi->center[1], cdsi->center[2]); */
 
         cdsi->scale = scale_log_met3(n, gamma, phi, oldscale, r2, sm, width, skip);
+        //skip = 1;
+        //cdsi->scale = scale_rejection(n, gamma, phi, r2);
         ScaleCds(cdsi, cdsi->scale / oldscale);
 
-        printf("\n(diag) scale[%3d]: % f % f % f % f % f", i+1, cdsi->scale, phi, gamma, sm, width);
-        fflush(NULL);
+        //printf("\n(diag) scale[%3d]: % f % f % f % f % f", i+1, cdsi->scale, phi, gamma, sm, width);
+        //fflush(NULL);
     }
 }
 
@@ -684,8 +702,8 @@ GibbsPhi(CdsArray *cdsA, const gsl_rng *r2)
     for (i = 0; i < vlen; ++i)
         invtr += 1.0 / cdsA->var[i];
 
-    a = 0.5 * (vlen + 1.0);
-    b = 2.0 / (invtr + 1.0 / cdsA->stats->alpha);
+    a = 0.5 * (vlen + 2.0);
+    b = 2.0 / (invtr + 2.0 / cdsA->stats->alpha);
 
     cdsA->stats->phi = gsl_ran_gamma(r2, a, b);
 
@@ -785,14 +803,17 @@ GibbsMeanWrite(CdsArray *cdsA, const gsl_rng *r2, const int iter)
 {
     int             i;
     Cds         *avecds = cdsA->avecds;
-    const int       vlen = cdsA->vlen, cnum = cdsA->cnum;
+//    const int       vlen = cdsA->vlen;
+    const int       cnum = cdsA->cnum;
     char            filename[256];
 
+/* 
     for (i = 0; i < vlen; ++i)
         cdsA->w[i] = 1.0 / cdsA->stats->var;
+ */
 
 //    AveCdsGibbs(cdsA);
-    GibbsMean(cdsA, r2);
+//    GibbsMean(cdsA, r2);
 // 
 //     CenMass(avecds);
 //     ApplyCenterIp(avecds);
@@ -804,11 +825,24 @@ GibbsMeanWrite(CdsArray *cdsA, const gsl_rng *r2, const int iter)
     for (i = 0; i < cnum; ++i)
         RotateCdsIp(cdsA->cds[i], (const double **) avecds->matrix);
 
+    double sum = 0.0;
+
+    for (i = 0; i < cnum; ++i)
+        sum += log(cdsA->cds[i]->scale);
+
+    sum = exp(sum/cnum);
+
+    for (i = 0; i < cnum; ++i)
+        ScaleCds(cdsA->cds[i], 1.0/sum);
+
     sprintf(filename, "%s%05d.pdb", "gibbs_", iter);
 /*     printf("\nWriting %s", filename); */
 /*     fflush(NULL); */
     WriteTheseusCdsModelFile(cdsA, filename);
 
+    for (i = 0; i < cnum; ++i)
+        ScaleCds(cdsA->cds[i], sum);
+
     GibbsMean(cdsA, r2);
 }
 
@@ -818,14 +852,15 @@ GibbsMeanDiagWrite(CdsArray *cdsA, const gsl_rng *r2, const int iter)
 {
     int             i;
     Cds         *avecds = cdsA->avecds;
-    const int       vlen = cdsA->vlen, cnum = cdsA->cnum;
+    //const int       vlen = cdsA->vlen;
+    const int       cnum = cdsA->cnum;
     char            filename[256];
 
     //AveCdsGibbs(cdsA);
     GibbsMeanDiag(cdsA, r2);
 
-    for (i = 0; i < vlen; ++i)
-        cdsA->w[i] = 1.0;
+//    for (i = 0; i < vlen; ++i)
+//        cdsA->w[i] = 1.0;
 //         cdsA->w[i] = 1.0 / cdsA->var[i];
 // 
 //     CenMassWtIp(avecds, cdsA->w);
@@ -856,7 +891,7 @@ GibbsTrans(CdsArray *cdsA, const gsl_rng *r2)
     int             i;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
     double          var = cdsA->stats->var;
-    double          tvar = sqrt(var / vlen);
+    double          tvar = sqrt(var / vlen), tvarbeta;
     Cds         *cdsi = NULL;
 
 /*     printf("\ntvar: % e", tvar); */
@@ -871,9 +906,11 @@ GibbsTrans(CdsArray *cdsA, const gsl_rng *r2)
 /*         printf("\nB trans[%d]: % f % f % f", i+1,  */
 /*                cdsi->center[0], cdsi->center[1], cdsi->center[2]); */
 
-        cdsi->center[0] += gsl_ran_gaussian(r2, tvar);
-        cdsi->center[1] += gsl_ran_gaussian(r2, tvar);
-        cdsi->center[2] += gsl_ran_gaussian(r2, tvar);
+        tvarbeta = tvar/cdsi->scale;
+
+        cdsi->center[0] += gsl_ran_gaussian(r2, tvarbeta);
+        cdsi->center[1] += gsl_ran_gaussian(r2, tvarbeta);
+        cdsi->center[2] += gsl_ran_gaussian(r2, tvarbeta);
 
 /*         printf("\nA trans[%d]: % f % f % f\n", i+1,  */
 /*                cdsA->cds[i]->center[0], cdsA->cds[i]->center[1], cdsA->cds[i]->center[2]); */
@@ -889,8 +926,8 @@ GibbsTransDiag(CdsArray *cdsA, const gsl_rng *r2)
 {
     int             i;
     const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
-    double          tvar, invtr;
-    Cds         *cdsi = NULL;
+    double          tvar, invtr, tvarbeta;
+    Cds            *cdsi = NULL;
 
     invtr = 0.0;
     for (i = 0; i < vlen; ++i)
@@ -912,9 +949,11 @@ GibbsTransDiag(CdsArray *cdsA, const gsl_rng *r2)
 /*         printf("\nB trans[%d]: % f % f % f", i+1,  */
 /*                cdsi->center[0], cdsi->center[1], cdsi->center[2]); */
 
-        cdsi->center[0] += gsl_ran_gaussian(r2, tvar);
-        cdsi->center[1] += gsl_ran_gaussian(r2, tvar);
-        cdsi->center[2] += gsl_ran_gaussian(r2, tvar);
+        tvarbeta = tvar/cdsi->scale;
+
+        cdsi->center[0] += gsl_ran_gaussian(r2, tvarbeta);
+        cdsi->center[1] += gsl_ran_gaussian(r2, tvarbeta);
+        cdsi->center[2] += gsl_ran_gaussian(r2, tvarbeta);
 
         //cdsi->center[2] = 0.0;
 
@@ -1041,13 +1080,14 @@ MardiaRot3(double *R, const double *t)
 //     R[8] = c2*c3;
 }
 
+
 /* See:
    Green and Mardia (2006)
    "Bayesian alignment using hierarchical models, with applications in protein bioinformatics"
    Biometrika 93(2):235254 
    Esp. pp 241-242.
 */
-static void
+void
 GibbsMetRot(CdsArray *cdsA, double **theta, const gsl_rng *r2)
 {
     int             i, j, k;
@@ -1066,22 +1106,23 @@ GibbsMetRot(CdsArray *cdsA, double **theta, const gsl_rng *r2)
                                /* I simply offet the structures by a "location parameter". */
                                /* I do the same for the translations. */
                                /* We can't do this if the chains are run out of place */
-        if (cdsA->algo->varweight > 0)
-            CdsInnerProduct(&F[0][0], ave, cdsA->cds[i], vlen, cdsA->w);
-        else
-            CdsInnerProduct(&F[0][0], ave, cdsA->cds[i], vlen, NULL);
+            
 /*         printf("\n\n****************\nstructure: %d", i+1); */
 /*         printf("\nF:"); */
 /*         Mat3Print(F); */
 
         if (cdsA->algo->varweight > 0)
         {
+            CdsInnerProduct(&F[0][0], ave, cdsA->cds[i], vlen, cdsA->w);
+
             for (j = 0; j < 3; ++j)
                 for (k = 0; k < 3; ++k)
                     F[j][k] /= 2.0;
         }
         else
         {
+            CdsInnerProduct(&F[0][0], ave, cdsA->cds[i], vlen, NULL);
+
             for (j = 0; j < 3; ++j)
                 for (k = 0; k < 3; ++k)
                     F[j][k] /= (2.0 * var);
@@ -1138,6 +1179,157 @@ GibbsMetRot(CdsArray *cdsA, double **theta, const gsl_rng *r2)
 }
 
 
+static int
+CalcRotMat(double **rotmat, double **Umat, double *s, double **Vtmat)
+{   
+    int         i, j, k;
+    double      det;
+
+    memset(&rotmat[0][0], 0, 9 * sizeof(double));
+
+    det = Mat3Det((const double **)Umat) * Mat3Det((const double **)Vtmat);
+
+    if (det > 0)
+    {
+        for (i = 0; i < 3; ++i)
+            for (j = 0; j < 3; ++j)
+                for (k = 0; k < 3; ++k)
+                    rotmat[i][j] += (Vtmat[k][i] * s[k] * Umat[j][k]);
+
+        return(1);
+    }
+    else
+    {
+        /* printf("\n * determinant of SVD U or V matrix = %f", det); */
+
+        for (i = 0; i < 3; ++i)
+        {
+            for (j = 0; j < 3; ++j)
+            {
+                for (k = 0; k < 2; ++k)
+                    rotmat[i][j] += (Vtmat[k][i] * s[k] * Umat[j][k]);
+
+                rotmat[i][j] -= (Vtmat[2][i] * Umat[j][2]);
+            }
+        }
+
+        return(-1);
+    }
+}
+
+
+static int
+CalcGSLSVD(double **Rmat, double **Umat, double *sigma, double **VTmat)
+{
+    svdGSLDest(Rmat, 3, sigma, VTmat);
+    Mat3TransposeIp(VTmat);
+    Mat3Cpy(Umat, (const double **) Rmat);
+    return(1);
+}
+
+
+/* See:
+   Habeck (2009)
+   "Generation of three-dimensional random rotations in fitting and matching problems."
+   Comput Stat 24:719-731
+   
+   NB: broken, for now -- probably a transpose issue somewhere, either rotmat or V (should be Vt?)
+*/
+void
+GibbsRot(CdsArray *cdsA, double **theta, const gsl_rng *r2)
+{
+    int             i, j, k;
+    const int       cnum = cdsA->cnum, vlen = cdsA->vlen;
+    double          var = cdsA->stats->var;
+    double        **A = cdsA->tmpmat3a;
+    Cds            *ave = cdsA->avecds;
+    double          alpha, beta, gamma, phi, psi, u, r, x, kappab, kappaphi, kappapsi, tmpa, tmpb;
+    double        **rotmat = NULL;
+    double        **V = cdsA->tmpmat3b;
+    double         *lambda = malloc(3 * sizeof(double));
+    double          a = 0.0;
+
+    for (i = 0; i < cnum; ++i)
+    {
+        if (cdsA->algo->varweight > 0)
+            CdsInnerProduct(&A[0][0], ave, cdsA->cds[i], vlen, cdsA->w);
+        else
+            CdsInnerProduct(&A[0][0], ave, cdsA->cds[i], vlen, NULL);
+/*         printf("\n\n****************\nstructure: %d", i+1); */
+/*         printf("\nF:"); */
+/*         Mat3Print(F); */
+
+        if (cdsA->algo->varweight > 0)
+        {
+            for (j = 0; j < 3; ++j)
+                for (k = 0; k < 3; ++k)
+                    A[j][k] *= 0.5;
+        }
+        else
+        {
+            for (j = 0; j < 3; ++j)
+                for (k = 0; k < 3; ++k)
+                    A[j][k] /= (2.0 * var);
+        }
+
+        rotmat = cdsA->cds[i]->matrix;
+
+        CalcGSLSVD(rotmat, A, lambda, V);
+        //svdGSLDest(A, 3, lambda, V);
+
+        beta = theta[i][1];
+
+        for (i = 0; i < 7; ++i)
+        {
+            tmpa = cos(0.5 * beta);
+            tmpb = sin(0.5 * beta);
+    
+            kappaphi = tmpa*tmpa * (lambda[0] + lambda[1]);
+            kappapsi = tmpb*tmpb * (lambda[0] - lambda[1]);
+    
+            phi = vonmises_dev(a, kappaphi, r2);
+            psi = vonmises_dev(a, kappapsi, r2);
+            u = gsl_ran_bernoulli (r2, 0.5);
+    
+            alpha = 0.5 * (phi + psi) + M_PI * u;
+            gamma = 0.5 * (phi - psi) + M_PI * u;
+    
+            kappab = (lambda[0] + lambda[1]) * cos(phi) + (lambda[0] - lambda[1]) * cos(psi) + 2.0 * lambda[2];
+            r = gsl_rng_uniform(r2);
+            x = 1.0 + 2.0 * log(r + (1.0 -r) * exp(-kappab))/kappab;
+            beta = acos(x);
+        }
+
+        CalcRotMat(rotmat, A, lambda, V);
+
+/*         printf("\ntheta: % f % f % f\n", theta[i][0], theta[i][1], theta[i][2]); */
+
+        theta[i][0] = alpha;
+        theta[i][1] = beta;
+        theta[i][2] = gamma;
+        MardiaRot3(&rotmat[0][0], theta[i]);
+
+/*         printf("\nrotmat:"); */
+/*         Mat3Print(rotmat); */
+/*         fflush(NULL); */
+/*  */
+/*         if (VerifyRotMat(rotmat, 1e-6) == 0) */
+/*         { */
+/*             printf("\nBAD ROTATION MATRIX\n\n"); */
+/*             exit(EXIT_FAILURE); */
+/*         } */
+
+        theta[i][1] = beta;
+
+        Mat3TransposeIp(rotmat);
+
+        RotateCdsIp(cdsA->cds[i], (const double **) rotmat);
+    }
+    
+    free(lambda);
+}
+
+
 static void
 WriteSample(FILE *paramfile, CdsArray *cdsA, double **theta, const int iter)
 {
@@ -1386,7 +1578,7 @@ GibbsMet(CdsArray *cdsA)
     gsl_rng                *r2 = NULL;
     double                  invtr, mlik, hmlik, blik, amlik, diff, ediff, liksi;
     int                     badsamp, nsamp, burnin = 100;
-    Cds                 *avecds = cdsA->avecds;
+    Cds                    *avecds = cdsA->avecds;
     FILE                   *paramfile = NULL;
 
     double *liks = malloc(burn * sizeof(double));
@@ -1456,7 +1648,7 @@ GibbsMet(CdsArray *cdsA)
     {
         //ScaleCds(cdsA->cds[i], i+1.0);
         //cdsA->cds[i]->scale = i+1.0;
-        cdsA->cds[i]->scale = 15;
+        //cdsA->cds[i]->scale = 1.0;
     }
 
     VarCds(cdsA);
@@ -1470,8 +1662,9 @@ GibbsMet(CdsArray *cdsA)
             GibbsVarDiag(cdsA, r2);
             GibbsMeanDiag(cdsA, r2);
             GibbsTransDiag(cdsA, r2);
+            //GibbsRot(cdsA, theta, r2);
             GibbsMetRot(cdsA, theta, r2);
-            if (cdsA->algo->scale == 1)
+            if (cdsA->algo->scale > 0)
                 MetScaleDiag(cdsA, r2);
         }
         else
@@ -1479,8 +1672,9 @@ GibbsMet(CdsArray *cdsA)
             GibbsVar(cdsA, r2);
             GibbsMean(cdsA, r2);
             GibbsTrans(cdsA, r2);
+            //GibbsRot(cdsA, theta, r2);
             GibbsMetRot(cdsA, theta, r2);
-            if (cdsA->algo->scale == 1)
+            if (cdsA->algo->scale > 0)
                 MetScale(cdsA, r2);
         }
 
