@@ -27,6 +27,6 @@
 #define GIBBSMET_SEEN
 
 void
-GibbsMet(CoordsArray *cdsA);
+GibbsMet(CdsArray *cdsA);
 
 #endif
