@@ -31,11 +31,11 @@
 #include "Error.h"
 #include "lodmats.h"
 #include "pdbMalloc.h"
-#include "Coords.h"
-#include "PDBCoords.h"
+#include "Cds.h"
+#include "PDBCds.h"
 #include "MultiPose2MSA.h"
-#include "ProcLAPACKSVD.h"
-#include "ProcLAPACKSVDOcc.h"
+#include "ProcGSLSVD.h"
+#include "ProcGSLSVDOcc.h"
 #include "msa.h"
 
 
@@ -110,7 +110,7 @@ aa1toaa3(char aa1_c, char *aa3_s)
 
 
 static void
-VerifyAlignmentVsPDBs(PDBCoordsArray *pdbA, CoordsArray *baseA, MSA *msa,
+VerifyAlignmentVsPDBs(PDBCdsArray *pdbA, CdsArray *baseA, MSA *msa,
                       const int atomsel, int *map)
 {
     int             i, j, len, aalen;
@@ -127,17 +127,17 @@ VerifyAlignmentVsPDBs(PDBCoordsArray *pdbA, CoordsArray *baseA, MSA *msa,
                 ++len;
 
         aalen = 0;
-	    for (j = 0; j < pdbA->coords[i]->vlen; ++j)
-			if (atom_selxn(pdbA->coords[i]->name[j], atomsel) == 1 &&
-			    (pdbA->coords[i]->altLoc[j] == ' ' || pdbA->coords[i]->altLoc[j] == 'A'))
+	    for (j = 0; j < pdbA->cds[i]->vlen; ++j)
+			if (atom_selxn(pdbA->cds[i]->name[j], atomsel) == 1 &&
+			    (pdbA->cds[i]->altLoc[j] == ' ' || pdbA->cds[i]->altLoc[j] == 'A'))
 			    ++aalen;
 
-        baseA->coords[i]->aalen = aalen;
+        baseA->cds[i]->aalen = aalen;
 
         if (len != aalen)
         {
 			fprintf(stderr, "\n\n  ERROR1122: PDB file '%s' and sequence '%s' in '%s'",
-			        pdbA->coords[i]->filename, msa->name[map[i]], msa->filename);
+			        pdbA->cds[i]->filename, msa->name[map[i]], msa->filename);
 			fprintf(stderr, "\n            have different lengths (%d vs %d)\n\n",
 			       aalen, len);
             PrintTheseusTag();
@@ -147,10 +147,10 @@ VerifyAlignmentVsPDBs(PDBCoordsArray *pdbA, CoordsArray *baseA, MSA *msa,
 }
 
 
-/* Dumps the indices from a multiple sequence alignment into the segID field of pdb coords
+/* Dumps the indices from a multiple sequence alignment into the segID field of pdb cds
    2010-10-12 */
 void
-Align2segID(PDBCoordsArray *pdbA)
+Align2segID(PDBCdsArray *pdbA)
 {
     int             i, j, k;
     const int       cnum = pdbA->cnum;
@@ -159,12 +159,12 @@ Align2segID(PDBCoordsArray *pdbA)
     char           *seq = NULL;
     int             resSeq = 0;
     char            alnindex[5];
-    PDBCoords      *cdsi = NULL;
+    PDBCds      *cdsi = NULL;
 
     for (i = 0; i < cnum; ++i)
     {
-        cdsi = pdbA->coords[i];
-        k = 0; /* PDBCoords index */
+        cdsi = pdbA->cds[i];
+        k = 0; /* PDBCds index */
         j = 0; /* MSA index */
         seq = msa->seq[map[i]];
 /* printf("\n\n%s\n%s", cdsi->filename, seq); */
@@ -199,7 +199,7 @@ Align2segID(PDBCoordsArray *pdbA)
    residues in the sequence alignment.
    2010-10-12 */
 void
-Align2Vars(PDBCoordsArray *pdbA, CoordsArray *cdsA)
+Align2Vars(PDBCdsArray *pdbA, CdsArray *cdsA)
 {
     int             i, j, k, m;
     const int       cnum = pdbA->cnum;
@@ -207,21 +207,23 @@ Align2Vars(PDBCoordsArray *pdbA, CoordsArray *cdsA)
     MSA            *msa = pdbA->seq2pdb->msa;
     char           *seq = NULL;
     int             resSeq = 0;
-    PDBCoords      *cdsi = NULL;
+    PDBCds      *cdsi = NULL;
     int            *singletons = pdbA->seq2pdb->singletons;
 
     for (i = 0; i < cnum; ++i)
-        for (j = 0; j < pdbA->coords[i]->vlen; ++j)
-            pdbA->coords[i]->tempFactor[j] = 0.0;
+        for (j = 0; j < pdbA->cds[i]->vlen; ++j)
+            pdbA->cds[i]->tempFactor[j] = 0.0;
 
     for (i = 0; i < cnum; ++i)
     {
-        cdsi = pdbA->coords[i];
-        k = 0; /* PDBCoords index */
+        cdsi = pdbA->cds[i];
+        k = 0; /* PDBCds index */
         j = 0; /* MSA index */
-        m = 0; /* coords variances index */
+        m = 0; /* cds variances index */
         seq = msa->seq[map[i]];
 /* printf("\n\n%s\n%s", cdsi->filename, seq); */
+        /* if we put "m < cdsA->vlen" in here also, we miss hanging singletons (at the end of a
+           MSA).  So we check that m is OK before accessing it. */
         while (j < msa->seqlen && k < cdsi->vlen)
         {
             if (singletons[j] == 1)
@@ -354,16 +356,16 @@ static Seq2PDB
 }
 
 
-/* Constructs an integer vector that maps a Coords structure to a sequence name in the alignment */
+/* Constructs an integer vector that maps a Cds structure to a sequence name in the alignment */
 /* First matches PDB filename to the PDB filename given in the mapfile.
    Every filename in the mapfile is associated with a sequence name of the same index.
    Then the fxn matches the sequence name in the mapfile with a sequence name in the alignment.
    Given these two matchings and the mapfile, the map[] vector can be constructed.
-   Finally, given Coords i, then map[i] = k, where k is the index of the corresponding
+   Finally, given Cds i, then map[i] = k, where k is the index of the corresponding
    sequence in the MSA.
    NB: filename extensions are ignored. */
 static void
-GetSeq2PDBMap(PDBCoordsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
+GetSeq2PDBMap(PDBCdsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
 {
     int             i, j, k, str1len, str2len, str3len, str4len;
     const int       cnum = pdbA->cnum;
@@ -382,7 +384,7 @@ GetSeq2PDBMap(PDBCoordsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
     {
         for (j = 0; j < seq2pdb->seqnum; ++j)
         {
-            filename_root = getroot(pdbA->coords[i]->filename);
+            filename_root = getroot(pdbA->cds[i]->filename);
             mappdbname_root = getroot(seq2pdb->pdbfile_name[j]);
             mapseqname_root = getroot(seq2pdb->seqname[j]);
 
@@ -404,7 +406,7 @@ GetSeq2PDBMap(PDBCoordsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
                     //printf("\ni:%3d j:%3d k:%3d -- %s %s %s", i, j, k, filename_root, mapseqname_root, msaname_root);
 
                     if ((strncmp(mapseqname_root, msaname_root, str3len) == 0) &&
-                        (str3len == str4len)) /* now k (alignment) and i (pdb coords) match */
+                        (str3len == str4len)) /* now k (alignment) and i (pdb cds) match */
                     {
                         //printf("\nMATCH");
                         pdbA->seq2pdb->map[i] = k;
@@ -444,7 +446,7 @@ GetSeq2PDBMap(PDBCoordsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
         {
 			fprintf(stderr,
 					"\n  ERROR_690: PDB file #%d (%s) has no corresponding sequence in the alignment\n",
-					i+1, pdbA->coords[i]->filename);
+					i+1, pdbA->cds[i]->filename);
 			PrintTheseusTag();
 			exit(EXIT_FAILURE);
         }
@@ -455,7 +457,7 @@ GetSeq2PDBMap(PDBCoordsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
 /* Same as above, but no mapfile needed as we assume that the sequence names and 
    PDB file names are identical */
 static void
-DefaultSeq2PDBMap(PDBCoordsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
+DefaultSeq2PDBMap(PDBCdsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
 {
     int             i, j;
     const int       cnum = pdbA->cnum;
@@ -471,12 +473,12 @@ DefaultSeq2PDBMap(PDBCoordsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
     {
         for (j = 0; j < msa->seqnum; ++j)
         {
-            strncpy(filename_root, getroot(pdbA->coords[i]->filename), strlen(pdbA->coords[i]->filename)+1);
+            strncpy(filename_root, getroot(pdbA->cds[i]->filename), strlen(pdbA->cds[i]->filename)+1);
             strncpy(msaname_root, getroot(msa->name[j]), strlen(msa->name[j])+1);
 
             if (strncmp(filename_root, msaname_root, FILENAME_MAX) == 0)
             {
-                seq2pdb->map[i] = j; /* now j (alignment) and i (pdb coords) match */
+                seq2pdb->map[i] = j; /* now j (alignment) and i (pdb cds) match */
                 msa->flag[j] = 0; /* reset msa flag to 0 since this structure exists */
                 break;
             }
@@ -486,7 +488,7 @@ DefaultSeq2PDBMap(PDBCoordsArray *pdbA, Seq2PDB *seq2pdb, MSA *msa)
         {
 			fprintf(stderr,
 					"\n  ERROR690: PDB file #%d (%s) has no corresponding sequence in the alignment\n",
-					i+1, pdbA->coords[i]->filename);
+					i+1, pdbA->cds[i]->filename);
 			PrintTheseusTag();
 			exit(EXIT_FAILURE);
         }
@@ -548,7 +550,7 @@ GetUbiqs(int *ubiqs, MSA *msa)
 
 
 static void
-GetCoordsFrAlignment(PDBCoordsArray *pdbA, CoordsArray *baseA,
+GetCdsFrAlignment(PDBCdsArray *pdbA, CdsArray *baseA,
                      Seq2PDB *seq2pdb, MSA *msa,
                      const int vlen, const int alignlen,
                      int *singletons)
@@ -564,52 +566,52 @@ GetCoordsFrAlignment(PDBCoordsArray *pdbA, CoordsArray *baseA,
 	{
 	    k = map[j];
 		m = n = p = 0;
-		while(m < pdbA->coords[j]->vlen && n < vlen  && p < alignlen)
+		while(m < pdbA->cds[j]->vlen && n < vlen  && p < alignlen)
 		{
 			/* m = PDB length */
-			/* n = baseA coords length */
+			/* n = baseA cds length */
 			/* p = sequence alignment length */
 			/* k = sequence index */
-			/* j = pdb and baseA coords index */
+			/* j = pdb and baseA cds index */
 
-/*                             printf("\n1 n:%d(%d) atomname:pdbA->coords[%d]->name[%d] %s", */
-/*                                    n, alignlen, j, m, pdbA->coords[j]->name[m]); */
+/*                             printf("\n1 n:%d(%d) atomname:pdbA->cds[%d]->name[%d] %s", */
+/*                                    n, alignlen, j, m, pdbA->cds[j]->name[m]); */
 /*                             fflush(NULL); */
 /* if (j == cnum - 1) */
-/* printf("\naltLoc:%c", pdbA->coords[j]->altLoc[m]); */
-			if (atom_selxn(pdbA->coords[j]->name[m], baseA->algo->atoms) == 1 &&
-			    (pdbA->coords[j]->altLoc[m] == ' ' || pdbA->coords[j]->altLoc[m] == 'A'))
+/* printf("\naltLoc:%c", pdbA->cds[j]->altLoc[m]); */
+			if (atom_selxn(pdbA->cds[j]->name[m], baseA->algo->atoms) == 1 &&
+			    (pdbA->cds[j]->altLoc[m] == ' ' || pdbA->cds[j]->altLoc[m] == 'A'))
 			{
 /*                                 printf("\n1 m:%d(%d) msa->seq[%d(%d)][%d(%d)] = %c", */
-/*                                        m, pdbA->coords[j]->vlen, k, cnum, n, alignlen, msa->seq[k][n]); */
+/*                                        m, pdbA->cds[j]->vlen, k, cnum, n, alignlen, msa->seq[k][n]); */
 /*                                 fflush(NULL); */
 				if (range_selxn(p, lower, upper, range_num) == 1 - baseA->algo->revsel && /* in-range, or out-of-range if revsel == 1 */
 				    singletons[p] == 0) /* not a singleton */
 				{
 					if (msa->seq[k][p] != '-') /* not a gap */
 					{
-						strncpy(baseA->coords[j]->resName[n], pdbA->coords[j]->resName[m], 3);
-						baseA->coords[j]->chainID[n] = pdbA->coords[j]->chainID[m];
-						baseA->coords[j]->resSeq[n]  = pdbA->coords[j]->resSeq[m];
-						baseA->coords[j]->x[n]       = pdbA->coords[j]->x[m];
-						baseA->coords[j]->y[n]       = pdbA->coords[j]->y[m];
-						baseA->coords[j]->z[n]       = pdbA->coords[j]->z[m];
-						baseA->coords[j]->o[n]       = 1.0;
-						baseA->coords[j]->b[n]       = pdbA->coords[j]->tempFactor[m];
+						strncpy(baseA->cds[j]->resName[n], pdbA->cds[j]->resName[m], 3);
+						baseA->cds[j]->chainID[n] = pdbA->cds[j]->chainID[m];
+						baseA->cds[j]->resSeq[n]  = pdbA->cds[j]->resSeq[m];
+						baseA->cds[j]->x[n]       = pdbA->cds[j]->x[m];
+						baseA->cds[j]->y[n]       = pdbA->cds[j]->y[m];
+						baseA->cds[j]->z[n]       = pdbA->cds[j]->z[m];
+						baseA->cds[j]->o[n]       = 1.0;
+						baseA->cds[j]->b[n]       = pdbA->cds[j]->tempFactor[m];
 
 						++m;
 						++n;
 					}
 					else /* is a gap */
 					{
-						strncpy(baseA->coords[j]->resName[n], "GAP", 3);
-						baseA->coords[j]->chainID[n] = pdbA->coords[j]->chainID[m];
-						baseA->coords[j]->resSeq[n]  = 0;
-						baseA->coords[j]->x[n]       = 0.0;
-						baseA->coords[j]->y[n]       = 0.0;
-						baseA->coords[j]->z[n]       = 0.0;
-						baseA->coords[j]->o[n]       = 0.0;
-						baseA->coords[j]->b[n]       = 99.99;
+						strncpy(baseA->cds[j]->resName[n], "GAP", 3);
+						baseA->cds[j]->chainID[n] = pdbA->cds[j]->chainID[m];
+						baseA->cds[j]->resSeq[n]  = 0;
+						baseA->cds[j]->x[n]       = 0.0;
+						baseA->cds[j]->y[n]       = 0.0;
+						baseA->cds[j]->z[n]       = 0.0;
+						baseA->cds[j]->o[n]       = 0.0;
+						baseA->cds[j]->b[n]       = 99.99;
 
 						++n;
 					}
@@ -626,7 +628,7 @@ GetCoordsFrAlignment(PDBCoordsArray *pdbA, CoordsArray *baseA,
 				++p;
 /* 				            if (j == cnum-1) */
 /*                                 printf("\n2 m:%d(%d) msa->seq[%d(%d)][%d(%d)] = %c", */
-/*                                        m, pdbA->coords[j]->vlen, k, cnum, n, alignlen, msa->seq[k][n]); */
+/*                                        m, pdbA->cds[j]->vlen, k, cnum, n, alignlen, msa->seq[k][n]); */
 /*                                 fflush(NULL); */
 			}
 			else /* not the proper atom slxn */
@@ -634,8 +636,8 @@ GetCoordsFrAlignment(PDBCoordsArray *pdbA, CoordsArray *baseA,
 				++m;
 			}
 /* 			            if (j == cnum-1) */
-/*                             printf("\n2 n:%d(%d) atomname:pdbA->coords[%d]->name[%d] %s", */
-/*                                    n, alignlen, j, m, pdbA->coords[j]->name[m]); */
+/*                             printf("\n2 n:%d(%d) atomname:pdbA->cds[%d]->name[%d] %s", */
+/*                                    n, alignlen, j, m, pdbA->cds[j]->name[m]); */
 /*                             fflush(NULL); */
 		}
 		/*******************************************************************************************/
@@ -643,18 +645,18 @@ GetCoordsFrAlignment(PDBCoordsArray *pdbA, CoordsArray *baseA,
 		if (n < vlen && m != 0 && n != 0)
 		{
 /* 		    printf("\nHere: m:%4d n:%4d p:%4d j:%4d -- %4d %4d %4d %4d", */
-/* 		            m, n, p, j, pdbA->coords[j]->vlen, vlen, alignlen, cnum); */
+/* 		            m, n, p, j, pdbA->cds[j]->vlen, vlen, alignlen, cnum); */
 
 			for (q = n; q < vlen; ++q)
 			{
-				strncpy(baseA->coords[j]->resName[q], "GAP", 3);
-				baseA->coords[j]->chainID[q] = pdbA->coords[j]->chainID[m-1];
-				baseA->coords[j]->resSeq[q]  = 0;
-				baseA->coords[j]->x[q]       = 0.0;
-				baseA->coords[j]->y[q]       = 0.0;
-				baseA->coords[j]->z[q]       = 0.0;
-				baseA->coords[j]->o[q]       = 0.0;
-				baseA->coords[j]->b[q]       = 66.66;
+				strncpy(baseA->cds[j]->resName[q], "GAP", 3);
+				baseA->cds[j]->chainID[q] = pdbA->cds[j]->chainID[m-1];
+				baseA->cds[j]->resSeq[q]  = 0;
+				baseA->cds[j]->x[q]       = 0.0;
+				baseA->cds[j]->y[q]       = 0.0;
+				baseA->cds[j]->z[q]       = 0.0;
+				baseA->cds[j]->o[q]       = 0.0;
+				baseA->cds[j]->b[q]       = 66.66;
 			}
 		}
 	}
@@ -662,7 +664,7 @@ GetCoordsFrAlignment(PDBCoordsArray *pdbA, CoordsArray *baseA,
 
 
 static int
-ParseSelxns(PDBCoordsArray *pdbA, char *selection, const int alignlen, int *singletons, const int revsel)
+ParseSelxns(PDBCdsArray *pdbA, char *selection, const int alignlen, int *singletons, const int revsel)
 {
     int             i, j, singleton_cnt;
     int             selxn_len, vlen;
@@ -687,7 +689,7 @@ ParseSelxns(PDBCoordsArray *pdbA, char *selection, const int alignlen, int *sing
         if (selections == NULL || pdbA->lower == NULL || pdbA->upper == NULL)
         {
             perror("\n  ERROR");
-            fprintf(stderr, " ERROR: could not allocate memory for selections in GetCoordsSelection(). \n\n");
+            fprintf(stderr, " ERROR: could not allocate memory for selections in GetCdsSelection(). \n\n");
             PrintTheseusTag();
             exit(EXIT_FAILURE);
         }
@@ -698,7 +700,7 @@ ParseSelxns(PDBCoordsArray *pdbA, char *selection, const int alignlen, int *sing
             if (selections[i] == NULL)
             {
                 perror("\n  ERROR");
-                fprintf(stderr, " ERROR: could not allocate memory for selections[] in GetCoordsSelection(). \n\n");
+                fprintf(stderr, " ERROR: could not allocate memory for selections[] in GetCdsSelection(). \n\n");
                 PrintTheseusTag();
                 exit(EXIT_FAILURE);
             }   
@@ -767,7 +769,7 @@ ParseSelxns(PDBCoordsArray *pdbA, char *selection, const int alignlen, int *sing
         if (selections == NULL || pdbA->lower == NULL || pdbA->upper == NULL || selections[0] == NULL)
         {
             perror("\n  ERROR");
-            fprintf(stderr, " ERROR989: could not allocate memory for selections in GetCoordsSelection(). \n\n");
+            fprintf(stderr, " ERROR989: could not allocate memory for selections in GetCdsSelection(). \n\n");
             PrintTheseusTag();
             exit(EXIT_FAILURE);
         }
@@ -825,7 +827,7 @@ ParseSelxns(PDBCoordsArray *pdbA, char *selection, const int alignlen, int *sing
 
 
 void
-Align2MSA(PDBCoordsArray *pdbA, CoordsArray *baseA, char *msafile_name, char *mapfile_name)
+Align2MSA(PDBCdsArray *pdbA, CdsArray *baseA, char *msafile_name, char *mapfile_name)
 {
     int             i, alnlen, vlen;
     const int       cnum = pdbA->cnum;
@@ -852,7 +854,7 @@ Align2MSA(PDBCoordsArray *pdbA, CoordsArray *baseA, char *msafile_name, char *ma
     if (msa->seqnum < pdbA->cnum)
     {
         fprintf(stderr,
-                "\n  ERROR682: # alignment sequences (%d) < # coords (%d)\n",
+                "\n  ERROR682: # alignment sequences (%d) < # cds (%d)\n",
                 msa->seqnum, pdbA->cnum);
         PrintTheseusTag();
         exit(EXIT_FAILURE);
@@ -890,10 +892,10 @@ Align2MSA(PDBCoordsArray *pdbA, CoordsArray *baseA, char *msafile_name, char *ma
 /*     } */
 //    printf("\n%d %d %d\n", msa->seqlen, alnlen, vlen);
 
-    /* allocate a CoordsArray based on this alignment */
+    /* allocate a CdsArray based on this alignment */
     if (algo->atoms == 0)
     {
-        CoordsArrayAlloc(baseA, cnum, vlen);
+        CdsArrayAlloc(baseA, cnum, vlen);
     }
     else
     {
@@ -904,22 +906,21 @@ Align2MSA(PDBCoordsArray *pdbA, CoordsArray *baseA, char *msafile_name, char *ma
     }
 
     for (i = 0; i < cnum; ++i)
-        strncpy(baseA->coords[i]->filename, pdbA->coords[i]->filename, FILENAME_MAX - 1);
+        strncpy(baseA->cds[i]->filename, pdbA->cds[i]->filename, FILENAME_MAX - 1);
 
     VerifyAlignmentVsPDBs(pdbA, baseA, msa, algo->atoms, pdbA->seq2pdb->map);
-    GetCoordsFrAlignment(pdbA, baseA, pdbA->seq2pdb, msa, vlen, alnlen, pdbA->seq2pdb->singletons);
+    GetCdsFrAlignment(pdbA, baseA, pdbA->seq2pdb, msa, vlen, alnlen, pdbA->seq2pdb->singletons);
 
 //    free(singletons);
 }
 
 
 double
-CalcRotationsOcc(CoordsArray *cdsA)
+CalcRotationsOcc(CdsArray *cdsA)
 {
-    Coords        **coords = cdsA->coords;
-    Coords         *avecoords = cdsA->avecoords;
+    Cds        **cds = cdsA->cds;
+    Cds         *avecds = cdsA->avecds;
     const double   *wts = (const double *) cdsA->w;
-    const double   *axesw = (const double *) cdsA->axesw;
     double          deviation = 0.0, deviation_sum = 0.0;
     int             i;
 
@@ -927,8 +928,8 @@ CalcRotationsOcc(CoordsArray *cdsA)
     {
         if(cdsA->algo->covweight != 0)
         {
-                deviation = ProcLAPACKSVDCovOcc(coords[i], avecoords, coords[i]->matrix,
-                                                (const double **) cdsA->WtMat, axesw,
+                deviation = ProcGSLSVDCovOcc(cds[i], avecds, cds[i]->matrix,
+                                                (const double **) cdsA->WtMat,
                                                 cdsA->tmpmat3a,
                                                 cdsA->tmpmat3b,
                                                 cdsA->tmpmat3c,
@@ -936,16 +937,16 @@ CalcRotationsOcc(CoordsArray *cdsA)
         }
         else if(cdsA->algo->varweight != 0 || cdsA->algo->leastsquares != 0)
         {
-                deviation = ProcLAPACKSVDOcc(coords[i], avecoords,
-                                             coords[i]->matrix,
-                                             wts, axesw,
+                deviation = ProcGSLSVDOcc(cds[i], avecds,
+                                             cds[i]->matrix,
+                                             wts,
                                              cdsA->tmpmat3a,
                                              cdsA->tmpmat3b,
                                              cdsA->tmpmat3c,
                                              cdsA->tmpvec3a);
         }
 
-        coords[i]->wRMSD_from_mean = sqrt(deviation / cdsA->vlen);
+        cds[i]->wRMSD_from_mean = sqrt(deviation / cdsA->vlen);
         deviation_sum += deviation;
 
         if (cdsA->algo->verbose == 1)
@@ -955,7 +956,7 @@ CalcRotationsOcc(CoordsArray *cdsA)
                since structure #2 is the average structure */
             printf("CalcRotationsOcc:%5d %8.3f %13.3f \n",
                    i+1,
-                   coords[i]->wRMSD_from_mean,
+                   cds[i]->wRMSD_from_mean,
                    deviation);
         }
     }
@@ -968,7 +969,7 @@ CalcRotationsOcc(CoordsArray *cdsA)
 /* char aa3[] = "ALAARGASNASPCYSGLNGLUGLYHISILELEULYSMETPHEPROSERTHRTRPTYRVAL"; */
 
 void
-pdb2fst(PDBCoordsArray *pdbA)
+pdb2fst(PDBCdsArray *pdbA)
 {
     int             i, j, count, aaindex;
     char           *pindex = NULL;
@@ -977,28 +978,28 @@ pdb2fst(PDBCoordsArray *pdbA)
 
     for (i = 0; i < pdbA->cnum; ++i)
     {
-        strncpy(outfile, pdbA->coords[i]->filename, strlen(pdbA->coords[i]->filename)+1);
+        strncpy(outfile, pdbA->cds[i]->filename, strlen(pdbA->cds[i]->filename)+1);
         strncat(outfile, ".fst", 4);
 
         fp = fopen(outfile, "w");
 
-        //fprintf(fp, ">%-72s", pdbA->coords[i]->filename);
-        fprintf(fp, ">%-s", pdbA->coords[i]->filename);
+        //fprintf(fp, ">%-72s", pdbA->cds[i]->filename);
+        fprintf(fp, ">%-s", pdbA->cds[i]->filename);
 
         count = 0;
-        for (j = 0; j < pdbA->coords[i]->vlen; ++j)
+        for (j = 0; j < pdbA->cds[i]->vlen; ++j)
         {
-            //printf("ATOM %4d:%4d \'%s\'\n", i, j, pdbA->coords[i]->name[j]);
+            //printf("ATOM %4d:%4d \'%s\'\n", i, j, pdbA->cds[i]->name[j]);
 
-            if ( (strncmp(pdbA->coords[i]->record[j], "ATOM  ", 6) == 0 || strncmp(pdbA->coords[i]->record[j], "HETATM", 6) == 0)
+            if ( (strncmp(pdbA->cds[i]->record[j], "ATOM  ", 6) == 0 || strncmp(pdbA->cds[i]->record[j], "HETATM", 6) == 0)
                 &&
-                (strncmp(pdbA->coords[i]->name[j], "CA ", 3) == 0 || strncmp(pdbA->coords[i]->name[j], "C1*", 3) == 0) &&
-                (pdbA->coords[i]->altLoc[j] == ' ' || pdbA->coords[i]->altLoc[j] == 'A'))
+                (strncmp(pdbA->cds[i]->name[j], "CA ", 3) == 0 || strncmp(pdbA->cds[i]->name[j], "C1*", 3) == 0) &&
+                (pdbA->cds[i]->altLoc[j] == ' ' || pdbA->cds[i]->altLoc[j] == 'A'))
             {
 				if (count % 72 == 0)
 					fputc('\n', fp);
 
-                pindex = strstr(aan3, pdbA->coords[i]->resName[j]);
+                pindex = strstr(aan3, pdbA->cds[i]->resName[j]);
                 if (pindex == NULL)
                     fputc('X', fp);
                 else
