@@ -30,32 +30,30 @@
 #include "MultiPose_local.h"
 #include "pdbStats.h"
 #include "distfit.h"
+#include "ProcGSLSVD.h"
 #include "MultiPoseMix.h"
 
 extern int
-MultiPose(CoordsArray *baseA);
+MultiPose(CdsArray *baseA);
 
 extern void
-PrintSuperposStats(CoordsArray *cdsA);
+PrintSuperposStats(CdsArray *cdsA);
 
 static void
-HierarchVars(CoordsArray *cdsA);
-
-static void
-LedoitWolfShrinkVar(CoordsArray *cdsA, int method);
+HierarchVars(CdsArray *cdsA);
 
 static int
-MultiPoseMix(CoordsArray *baseA, const double *probs, double *vars);
+MultiPoseMix(CdsArray *baseA, const double *probs, double *vars);
 
 static void
-CalcWtsMix(CoordsArray *cdsA, const double *probs);
+CalcWtsMix(CdsArray *cdsA, const double *probs);
 
 static void
 *MultiPoseMix_pth(void *mixdata_ptr);
 
 
 static double
-FrobTermAtom(CoordsArray *cdsA, const int atom)
+FrobTermAtom(CdsArray *cdsA, const int atom)
 {
     int             i;
     double          trace;
@@ -92,7 +90,7 @@ FrobTermAtom(CoordsArray *cdsA, const int atom)
    and the double matrix-weighted Frobenius norm must be calculated explicitly.
 */
 static double
-CalcLogLAtom(CoordsArray *cdsA, const int atom)
+CalcLogLAtom(CdsArray *cdsA, const int atom)
 {
     const double    cnum = cdsA->cnum;
     const double    nk = cnum;
@@ -163,14 +161,14 @@ CheckConvergenceMix(const double *vec1, const double *vec2, const int len, const
 
 
 void
-NewCalcMixDens(CoordsArray **mixA, const int mixn, double **probs)
+NewCalcMixDens(CdsArray **mixA, const int mixn, double **probs)
 {
     const int       vlen = mixA[0]->vlen, cnum = mixA[0]->cnum;
     double          dist, sump, pij, summix;
     int             i, j, k, m;
 
     for (j = 0; j < mixn; ++j)
-        AveCoords(mixA[j]);
+        AveCds(mixA[j]);
 
     for (m = 0; m < vlen; ++m)
     {
@@ -182,11 +180,11 @@ NewCalcMixDens(CoordsArray **mixA, const int mixn, double **probs)
                 summix = 0.0;
                 for (k = 0; k < mixn; ++k)
                 {
-                    dist = SqrCoordsDist(mixA[k]->coords[i], m, mixA[k]->avecoords, m);
+                    dist = SqrCdsDist(mixA[k]->cds[i], m, mixA[k]->avecds, m);
                     summix += probs[k][m] * normal_pdf(sqrt(dist), 0.0, 3.0 * mixA[k]->var[m]);
                 }
 
-                dist = SqrCoordsDist(mixA[j]->coords[i], m, mixA[j]->avecoords, m);
+                dist = SqrCdsDist(mixA[j]->cds[i], m, mixA[j]->avecds, m);
                 pij = probs[j][m] * normal_pdf(sqrt(dist), 0.0, 3.0 * mixA[j]->var[m]);
                 sump += pij / summix; 
             }
@@ -204,7 +202,7 @@ NewCalcMixDens(CoordsArray **mixA, const int mixn, double **probs)
 
 /*     for (i = 0; i < vlen; ++i) */
 /*     { */
-/*         printf("\n%3d:", mixA[0]->coords[0]->resSeq[i]); */
+/*         printf("\n%3d:", mixA[0]->cds[0]->resSeq[i]); */
 /*         for (j = 0; j < mixn; ++j) */
 /*             printf(" % 6.4f", probs[j][i]); */
 /*     } */
@@ -212,14 +210,14 @@ NewCalcMixDens(CoordsArray **mixA, const int mixn, double **probs)
 
 
 void
-OldCalcMixDens(CoordsArray **mixA, const int mixn, double **probs)
+OldCalcMixDens(CdsArray **mixA, const int mixn, double **probs)
 {
     const int       vlen = mixA[0]->vlen, cnum = mixA[0]->cnum;
     double          dist, sump;
     int             i, j, k, m;
 
     for (j = 0; j < mixn; ++j)
-        AveCoords(mixA[j]);
+        AveCds(mixA[j]);
 
     for (k = 0; k < mixn; ++k)
     {
@@ -227,7 +225,7 @@ OldCalcMixDens(CoordsArray **mixA, const int mixn, double **probs)
 		{
 			dist = 0.0;
 			for (j = 0; j < cnum; ++j)
-				dist += SqrCoordsDist(mixA[k]->coords[j], i, mixA[k]->avecoords, i);
+				dist += SqrCdsDist(mixA[k]->cds[j], i, mixA[k]->avecds, i);
 	
 			probs[k][i] *= normal_pdf(sqrt(dist), 0.0, 3.0 * cnum * mixA[k]->var[i]);
 		}
@@ -245,7 +243,7 @@ OldCalcMixDens(CoordsArray **mixA, const int mixn, double **probs)
 
 /*     for (i = 0; i < vlen; ++i) */
 /*     { */
-/*         printf("\n%3d:", mixA[0]->coords[0]->resSeq[i]); */
+/*         printf("\n%3d:", mixA[0]->cds[0]->resSeq[i]); */
 /*         for (j = 0; j < mixn; ++j) */
 /*             printf(" % 6.4f", probs[j][i]); */
 /*     } */
@@ -253,19 +251,19 @@ OldCalcMixDens(CoordsArray **mixA, const int mixn, double **probs)
 
 
 void
-CalcMixDens(CoordsArray *mixA, const double aveprob, double *probs)
+CalcMixDens(CdsArray *mixA, const double aveprob, double *probs)
 {
     const int       vlen = mixA->vlen, cnum = mixA->cnum;
     double          dist;
     int             i, j;
 
-    AveCoords(mixA);
+    AveCds(mixA);
 
     for (i = 0; i < vlen; ++i)
     {
         dist = 0.0;
         for (j = 0; j < cnum; ++j)
-            dist += SqrCoordsDist(mixA->coords[j], i, mixA->avecoords, i);
+            dist += SqrCdsDist(mixA->cds[j], i, mixA->avecds, i);
 
         probs[i] *= /* aveprob *  */normal_pdf(sqrt(dist), 0.0, 3.0 * cnum * mixA->var[i]);
     }
@@ -327,7 +325,7 @@ BinaryMixProbs(double **probs, const int mixn, const int vlen)
 
 
 void
-InitializeMix(CoordsArray *cdsA, double **probs)
+InitializeMix(CdsArray *cdsA, double **probs)
 {
     int             i, j;
     const int       vlen = cdsA->vlen, mixn = cdsA->algo->mixture;
@@ -380,7 +378,7 @@ InitializeMix(CoordsArray *cdsA, double **probs)
 
 
 void
-CalcSubsetProbs(CoordsArray **mixA, const int subset, double **probs)
+CalcSubsetProbs(CdsArray **mixA, const int subset, double **probs)
 {
     int             i, j, k, m;
     const int       vlen = mixA[0]->vlen, cnum = mixA[0]->cnum;
@@ -396,11 +394,11 @@ CalcSubsetProbs(CoordsArray **mixA, const int subset, double **probs)
 				summix = 0.0;
 				for (k = 0; k < subset - 1; ++k)
 				{
-					dist = SqrCoordsDist(mixA[k]->coords[i], m, mixA[k]->avecoords, m);
+					dist = SqrCdsDist(mixA[k]->cds[i], m, mixA[k]->avecds, m);
 					summix += probs[k][m] * normal_pdf(sqrt(dist), 0.0, 3.0 * mixA[k]->var[m]);
 				}
 
-				dist = SqrCoordsDist(mixA[j]->coords[i], m, mixA[j]->avecoords, m);
+				dist = SqrCdsDist(mixA[j]->cds[i], m, mixA[j]->avecds, m);
 				pij = probs[j][m] * normal_pdf(sqrt(dist), 0.0, 3.0 * mixA[j]->var[m]);
 				sump += pij / summix; 
 			}
@@ -431,7 +429,7 @@ CalcSubsetProbs(CoordsArray **mixA, const int subset, double **probs)
 
 
 void
-InitializeSubsets(CoordsArray **mixA, const int mixn, double **probs, double **vars)
+InitializeSubsets(CdsArray **mixA, const int mixn, double **probs, double **vars)
 {
     int             i, j, n, count;
     const int       vlen = mixA[0]->vlen;
@@ -462,7 +460,7 @@ InitializeSubsets(CoordsArray **mixA, const int mixn, double **probs, double **v
     for (n = 3; n < mixn; ++n)
     {
 		for (j = 0; j < n; ++j)
-			AveCoords(mixA[j]);
+			AveCds(mixA[j]);
 	
         CalcSubsetProbs(mixA, n, probs);
 
@@ -491,7 +489,7 @@ InitializeSubsets(CoordsArray **mixA, const int mixn, double **probs, double **v
 
 
 void
-InitializeSubsets_pth(CoordsArray **mixA, const int mixn, double **probs,
+InitializeSubsets_pth(CdsArray **mixA, const int mixn, double **probs,
                       pthread_t *callThd, pthread_attr_t *attr,
                       MixData **mixdata, double **vars)
 {
@@ -551,7 +549,7 @@ InitializeSubsets_pth(CoordsArray **mixA, const int mixn, double **probs,
     for (n = 3; n < mixn; ++n)
     {
 		for (j = 0; j < n; ++j)
-			AveCoords(mixA[j]);
+			AveCds(mixA[j]);
 	
         CalcSubsetProbs(mixA, n, probs);
 
@@ -608,7 +606,7 @@ InitializeSubsets_pth(CoordsArray **mixA, const int mixn, double **probs,
 
 
 void
-PrintMixtures(CoordsArray **mixA, const int mixn, double **probs, const int vlen)
+PrintMixtures(CdsArray **mixA, const int mixn, double **probs, const int vlen)
 {
     int             i, j;
 
@@ -624,12 +622,12 @@ PrintMixtures(CoordsArray **mixA, const int mixn, double **probs, const int vlen
             if (j >= vlen)
                 break;
 
-            printf("%d-", mixA[0]->coords[0]->resSeq[j]);
+            printf("%d-", mixA[0]->cds[0]->resSeq[j]);
 
             while (probs[i][j] > 0.5 && j < vlen)
                 ++j;
 
-            printf("%d", mixA[0]->coords[0]->resSeq[j-1]);
+            printf("%d", mixA[0]->cds[0]->resSeq[j-1]);
 
             if (j >= vlen)
                 break;
@@ -647,12 +645,12 @@ PrintMixtures(CoordsArray **mixA, const int mixn, double **probs, const int vlen
             if (j >= vlen)
                 break;
 
-            printf("%d-", mixA[0]->coords[0]->resSeq[j]);
+            printf("%d-", mixA[0]->cds[0]->resSeq[j]);
 
             while (probs[i][j] > 0.5 && j < vlen)
                 ++j;
 
-            printf("%d", mixA[0]->coords[0]->resSeq[j-1]);
+            printf("%d", mixA[0]->cds[0]->resSeq[j-1]);
 
             if (j >= vlen)
                 break;
@@ -667,7 +665,7 @@ PrintMixtures(CoordsArray **mixA, const int mixn, double **probs, const int vlen
 
 
 void
-PrintMixturesCols(CoordsArray **mixA, const int mixn, double **probs, const int vlen)
+PrintMixturesCols(CdsArray **mixA, const int mixn, double **probs, const int vlen)
 {
     int             i, j;
 
@@ -703,7 +701,7 @@ PrintMixturesCols(CoordsArray **mixA, const int mixn, double **probs, const int
 
 
 void
-CalcLRTs(CoordsArray **mixA, const int mixn, const int cnum, double **probs, const int vlen)
+CalcLRTs(CdsArray **mixA, const int mixn, const int cnum, double **probs, const int vlen)
 {
     double          dist, largest, smallest, logLR, sum;
     double         *logL = malloc(mixn * sizeof(double));
@@ -712,13 +710,13 @@ CalcLRTs(CoordsArray **mixA, const int mixn, const int cnum, double **probs, con
 
     for (i = 0; i < vlen; ++i)
     {
-        printf("Res: %4d\n", mixA[0]->coords[0]->resSeq[i]);
+        printf("Res: %4d\n", mixA[0]->cds[0]->resSeq[i]);
 
         for (j = 0; j < mixn; ++j)
         {
 			dist = 0.0;
 			for (k = 0; k < cnum; ++k)
-				dist += SqrCoordsDist(mixA[j]->coords[k], i, mixA[j]->avecoords, i);
+				dist += SqrCdsDist(mixA[j]->cds[k], i, mixA[j]->avecds, i);
 
             if (probs[j][i] == 0.0)
                 printf(" %10.3f", 0.0);
@@ -768,7 +766,7 @@ CalcLRTs(CoordsArray **mixA, const int mixn, const int cnum, double **probs, con
 
 
 static double
-CalcAICcorrxn(CoordsArray *cdsA)
+CalcAICcorrxn(CdsArray *cdsA)
 {
     double         n, p;
 
@@ -780,7 +778,7 @@ CalcAICcorrxn(CoordsArray *cdsA)
 
 
 static void
-CalcMixAICLogL(CoordsArray **mixA, const int mixn, const double **probs,
+CalcMixAICLogL(CdsArray **mixA, const int mixn, const double **probs,
                const int vlen, double *AIC, double *logL)
 {
     double          Lik;
@@ -816,7 +814,7 @@ CalcMixAICLogL(CoordsArray **mixA, const int mixn, const double **probs,
 
 
 int
-Mixture(CoordsArray *cdsA, PDBCoordsArray *pdbA)
+Mixture(CdsArray *cdsA, PDBCdsArray *pdbA)
 {
     int             count, i;
     const int       vlen = cdsA->vlen, cnum = cdsA->cnum, mixn = cdsA->algo->mixture;
@@ -824,26 +822,26 @@ Mixture(CoordsArray *cdsA, PDBCoordsArray *pdbA)
     double         *aveprobs = calloc(mixn, sizeof(double));
     int            *slope = calloc(mixn, sizeof(int));
     double         *oldprobs = calloc(vlen, sizeof(double));
-    CoordsArray   **mixA = NULL;
+    CdsArray   **mixA = NULL;
     Algorithm      *algo = cdsA->algo;
     /* Statistics     *stats = cdsA->stats; */
-    PDBCoordsArray *pdb2A = NULL;
+    PDBCdsArray *pdb2A = NULL;
     double        **newprobs = MatAlloc(vlen, cnum);
     double        **vars = MatAlloc(mixn, vlen);
     double          logL, AIC;
 
-    pdb2A = PDBCoordsArrayInit();
-    PDBCoordsArrayAlloc(pdb2A, pdbA->cnum, pdbA->vlen);
+    pdb2A = PDBCdsArrayInit();
+    PDBCdsArrayAlloc(pdb2A, pdbA->cnum, pdbA->vlen);
 
-    mixA = malloc(mixn * sizeof(CoordsArray *));
+    mixA = malloc(mixn * sizeof(CdsArray *));
 
     for (i = 0; i < mixn; ++i)
     {
         probs[i] = malloc(vlen * sizeof(double));
-        mixA[i] = CoordsArrayInit();
-        CoordsArrayAlloc(mixA[i], cnum, vlen);
-        CoordsArraySetup(mixA[i]);
-        CoordsArrayCopy(mixA[i], cdsA);
+        mixA[i] = CdsArrayInit();
+        CdsArrayAlloc(mixA[i], cnum, vlen);
+        CdsArraySetup(mixA[i]);
+        CdsArrayCopy(mixA[i], cdsA);
         mixA[i]->algo->write_file = 0;
     }
 
@@ -901,16 +899,16 @@ Mixture(CoordsArray *cdsA, PDBCoordsArray *pdbA)
 /*  */
 /*      for (j = 0; j < cnum; ++j) */
 /*      { */
-/*          PDBCoordsCopyAll(pdb2A->coords[j], pdbA->coords[j]); */
-/*          Mat3Cpy(pdb2A->coords[j]->matrix, (const double **) mixA[i]->coords[j]->matrix); */
-/*          memcpy(pdb2A->coords[j]->translation, mixA[i]->coords[j]->translation, 3 * sizeof(double)); */
+/*          PDBCdsCopyAll(pdb2A->cds[j], pdbA->cds[j]); */
+/*          Mat3Cpy(pdb2A->cds[j]->matrix, (const double **) mixA[i]->cds[j]->matrix); */
+/*          memcpy(pdb2A->cds[j]->translation, mixA[i]->cds[j]->translation, 3 * sizeof(double)); */
 /*      } */
 /*  */
-/*      Mat3Cpy(pdb2A->avecoords->matrix, (const double **) mixA[i]->avecoords->matrix); */
-/*      memcpy(pdb2A->avecoords->translation, mixA[i]->avecoords->translation, 3 * sizeof(double)); */
+/*      Mat3Cpy(pdb2A->avecds->matrix, (const double **) mixA[i]->avecds->matrix); */
+/*      memcpy(pdb2A->avecds->translation, mixA[i]->avecds->translation, 3 * sizeof(double)); */
 /*  */
 /*      for (j = 0; j < cnum; ++j) */
-/*          TransformPDBCoordsIp(pdb2A->coords[j]); */
+/*          TransformPDBCdsIp(pdb2A->cds[j]); */
 /*  */
 /*      if (algo->alignment == 1) */
 /*          Align2segID(pdb2A); */
@@ -925,20 +923,20 @@ Mixture(CoordsArray *cdsA, PDBCoordsArray *pdbA)
 /*          printf("\n    Writing transformed coordinates binary file ... "); */
 /*          fflush(NULL); */
 /*   */
-/*          WriteBinPDBCoordsArray(pdb2A); */
+/*          WriteBinPDBCdsArray(pdb2A); */
 /*      } */
 /*  */
 /*      printf("\n    Writing average coordinate file ... "); */
 /*      fflush(NULL); */
 /*  */
-/*      TransformCoordsIp(mixA[i]->avecoords); */
-/*      CopyCoords2PDB(pdb2A->avecoords, mixA[i]->avecoords); */
-/*      WriteAvePDBCoordsFile(pdb2A, mystrcat(algo->rootname, "_ave.pdb")); */
+/*      TransformCdsIp(mixA[i]->avecds); */
+/*      CopyCds2PDB(pdb2A->avecds, mixA[i]->avecds); */
+/*      WriteAvePDBCdsFile(pdb2A, mystrcat(algo->rootname, "_ave.pdb")); */
 /*     } */
 
     for (i = 0; i < mixn; ++i)
     {
-        CoordsArrayDestroy(&mixA[i]);
+        CdsArrayDestroy(&mixA[i]);
         free(probs[i]);
     }
 
@@ -947,7 +945,7 @@ Mixture(CoordsArray *cdsA, PDBCoordsArray *pdbA)
     free(aveprobs);
     free(slope);
     free(oldprobs);
-    PDBCoordsArrayDestroy(&pdb2A);
+    PDBCdsArrayDestroy(&pdb2A);
     MatDestroy(&newprobs);
     MatDestroy(&vars);
 
@@ -973,7 +971,7 @@ static void
 
 
 int
-Mixture_pth(CoordsArray *cdsA, PDBCoordsArray *pdbA)
+Mixture_pth(CdsArray *cdsA, PDBCdsArray *pdbA)
 {
     int             count, i, j, lineskip;
     const int       vlen = cdsA->vlen, cnum = cdsA->cnum, mixn = cdsA->algo->mixture;
@@ -982,7 +980,7 @@ Mixture_pth(CoordsArray *cdsA, PDBCoordsArray *pdbA)
     int            *slope = calloc(mixn, sizeof(int));
     double         *oldprobs = calloc(vlen, sizeof(double));
     double        **vars = MatAlloc(mixn, vlen);
-    CoordsArray   **mixA = NULL;
+    CdsArray   **mixA = NULL;
     Algorithm      *algo = cdsA->algo;
     double        **newprobs = MatAlloc(vlen, cnum);
     double          logL, AIC, Lik;
@@ -997,7 +995,7 @@ Mixture_pth(CoordsArray *cdsA, PDBCoordsArray *pdbA)
     for (i = 0; i < mixn; ++i)
         mixdata[i] = malloc(sizeof(MixData));
 
-    mixA = malloc(mixn * sizeof(CoordsArray *));
+    mixA = malloc(mixn * sizeof(CdsArray *));
 
     pthread_attr_init(&attr);
     pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_JOINABLE);
@@ -1009,10 +1007,10 @@ Mixture_pth(CoordsArray *cdsA, PDBCoordsArray *pdbA)
     for (i = 0; i < mixn; ++i)
     {
         probs[i] = malloc(vlen * sizeof(double));
-        mixA[i] = CoordsArrayInit();
-        CoordsArrayAlloc(mixA[i], cnum, vlen);
-        CoordsArraySetup(mixA[i]);
-        CoordsArrayCopy(mixA[i], cdsA);
+        mixA[i] = CdsArrayInit();
+        CdsArrayAlloc(mixA[i], cnum, vlen);
+        CdsArraySetup(mixA[i]);
+        CdsArrayCopy(mixA[i], cdsA);
         mixA[i]->algo->write_file = 0;
     }
 
@@ -1126,7 +1124,7 @@ Mixture_pth(CoordsArray *cdsA, PDBCoordsArray *pdbA)
 
     for (i = 0; i < mixn; ++i)
     {
-        CoordsArrayDestroy(&mixA[i]);
+        CdsArrayDestroy(&mixA[i]);
         free(probs[i]);
     }
 
@@ -1149,69 +1147,68 @@ Mixture_pth(CoordsArray *cdsA, PDBCoordsArray *pdbA)
 /* For superimposing to an alignment, we don't need to weight by occupancy
    since we are using pseudo-coordinates here from the E-M expectation step */
 static void
-CalcTranslations(CoordsArray *scratchA, Algorithm *algo)
+CalcTranslations(CdsArray *scratchA, Algorithm *algo)
 {
-    Coords        **coords = scratchA->coords;
+    Cds        **cds = scratchA->cds;
     int             i;
 
 	for (i = 0; i < scratchA->cnum; ++i)
 	{
 		if (algo->alignment == 1 && algo->rounds < 3)
-			CenMassWtIpOcc(coords[i], scratchA->w);
+			CenMassWtIpOcc(cds[i], scratchA->w);
 		else
-			CenMassWtIp(coords[i], scratchA->w);
+			CenMassWtIp(cds[i], scratchA->w);
 	}
 }
 
 
 static void
-MatDiagMultCoordsMultMatDiag(Coords *outcoords, const double *wtK, const Coords *coords, const double *wtD)
+MatDiagMultCdsMultMatDiag(Cds *outcds, const double *wtK, const Cds *cds)
 {
     int             i;
     double          wtKi;
-    const double   *x = (const double *) coords->x,
-                   *y = (const double *) coords->y,
-                   *z = (const double *) coords->z;
+    const double   *x = (const double *) cds->x,
+                   *y = (const double *) cds->y,
+                   *z = (const double *) cds->z;
 
-    for (i = 0; i < coords->vlen; ++i)
+    for (i = 0; i < cds->vlen; ++i)
     {
         wtKi = wtK[i];
 
-        outcoords->x[i] = wtKi * x[i] * wtD[0];
-        outcoords->y[i] = wtKi * y[i] * wtD[1];
-        outcoords->z[i] = wtKi * z[i] * wtD[2];
+        outcds->x[i] = wtKi * x[i];
+        outcds->y[i] = wtKi * y[i];
+        outcds->z[i] = wtKi * z[i];
     }
 }
 
 
 static double
-CalcRotations(CoordsArray *cdsA)
+CalcRotations(CdsArray *cdsA)
 {
-    Coords        **coords = cdsA->coords;
-    const Coords   *avecoords = cdsA->avecoords;
+    Cds        **cds = cdsA->cds;
+    const Cds   *avecds = cdsA->avecds;
     const double   *wts = (const double *) cdsA->w;
-    const double   *axesw = (const double *) cdsA->axesw;
-    Coords         *tcoords = cdsA->tcoords;
+    Cds         *tcds = cdsA->tcds;
     double          deviation = 0.0, deviation_sum = 0.0;
     int             i;
 
-	MatDiagMultCoordsMultMatDiag(tcoords, wts, avecoords, axesw);
+	MatDiagMultCdsMultMatDiag(tcds, wts, avecds);
 
 	for (i = 0; i < cdsA->cnum; ++i)
 	{
-		/* note that the avecoords are already multiplied by the weight matrices */
-		deviation = ProcLAPACKSVDvan(coords[i],
-									 tcoords,
-									 coords[i]->matrix,
+		/* note that the avecds are already multiplied by the weight matrices */
+		deviation = ProcGSLSVDvan(cds[i],
+									 tcds,
+									 cds[i]->matrix,
 									 cdsA->tmpmat3a,
 									 cdsA->tmpmat3b,
 									 cdsA->tmpmat3c,
 									 cdsA->tmpvec3a);
 
-/*      RotateCoordsIp(coords[i], (const double **) coords[i]->matrix); */
+/*      RotateCdsIp(cds[i], (const double **) cds[i]->matrix); */
 
-		/* find global rmsd and average coords (both held in structure) */
-		coords[i]->wRMSD_from_mean = sqrt(deviation / (3 * cdsA->vlen));
+		/* find global rmsd and average cds (both held in structure) */
+		cds[i]->wRMSD_from_mean = sqrt(deviation / (3 * cdsA->vlen));
 		deviation_sum += deviation;
 	}
 
@@ -1220,49 +1217,7 @@ CalcRotations(CoordsArray *cdsA)
 
 
 static void
-LedoitWolfShrinkVar(CoordsArray *cdsA, int method)
-{
-    switch(method)
-    {
-        case -1:
-        case 0:
-            break;
-
-        case 1: /* Preferred parametric */
-            CalcLedoitVarNewPar(cdsA);
-            break;
-
-        case 2: /* Preferred non-parametric */
-            CalcLedoitVarNew(cdsA);
-            break;
-
-        case 3:
-            CalcLedoitVar1Par(cdsA);
-            break;
-
-        case 4:
-            CalcLedoitVar1(cdsA);
-            break;
-
-        case 5:
-            CalcLedoitVar3(cdsA);
-            break;
-
-        case 6:
-            CalcSteinVar(cdsA);
-            break;
-
-        default:
-            printf("\n  ERROR:  Bad -L Ledoit-Wolf option \"%d\" \n", method);
-            Usage(0);
-            exit(EXIT_FAILURE);
-            break;
-    }
-}
-
-
-static void
-HierarchVars(CoordsArray *cdsA)
+HierarchVars(CdsArray *cdsA)
 {
     int             i;
     double          mean, mu, lambda, b, c, zeta, sigma;
@@ -1372,14 +1327,14 @@ HierarchVars(CoordsArray *cdsA)
 
 
 static int
-CheckConvergenceInner(CoordsArray *cdsA, const double precision)
+CheckConvergenceInner(CdsArray *cdsA, const double precision)
 {
     int             i;
 
     for (i = 0; i < cdsA->cnum; ++i)
     {
-        if (TestIdentMat((const double **) cdsA->coords[i]->matrix, 3, precision) == 0)
-        /* if (Mat3FrobEq((const double **) cdsA->coords[i]->last_matrix, (const double **) cdsA->coords[i]->matrix, precision) == 0) */
+        if (TestIdentMat((const double **) cdsA->cds[i]->matrix, 3, precision) == 0)
+        /* if (Mat3FrobEq((const double **) cdsA->cds[i]->last_matrix, (const double **) cdsA->cds[i]->matrix, precision) == 0) */
             return(0);
     }
 
@@ -1388,7 +1343,7 @@ CheckConvergenceInner(CoordsArray *cdsA, const double precision)
 
 
 static int
-CheckConvergenceOuter(CoordsArray *cdsA, int round, const double precision)
+CheckConvergenceOuter(CdsArray *cdsA, int round, const double precision)
 {
     Algorithm      *algo = cdsA->algo;
     int             i;
@@ -1406,7 +1361,7 @@ CheckConvergenceOuter(CoordsArray *cdsA, int round, const double precision)
         /* if (Mat3FrobEq((const double **) mat1, (const double **) mat2, algo->precision) == 0) */
         cdsA->stats->precision = 0.0;
         for (i = 0; i < cdsA->cnum; ++i)
-            cdsA->stats->precision += FrobDiffNormIdentMat((const double **) cdsA->coords[i]->matrix, 3);
+            cdsA->stats->precision += FrobDiffNormIdentMat((const double **) cdsA->cds[i]->matrix, 3);
         cdsA->stats->precision /= cdsA->cnum;
 
         if (cdsA->stats->precision > precision)
@@ -1421,38 +1376,42 @@ CheckConvergenceOuter(CoordsArray *cdsA, int round, const double precision)
 
 /* The real thing */
 static int
-MultiPoseMix(CoordsArray *baseA, const double *probs, double *vars)
+MultiPoseMix(CdsArray *baseA, const double *probs, double *vars)
 {
     int             i, round, innerround;
     int             slxn; /* index of random coord to select as first */
     double          deviation_sum = 0.0;
-    double        **lastmat = MatAlloc(3,3);
     const int       cnum = baseA->cnum;
     const int       vlen = baseA->vlen;
     double         *evals = malloc(3 * sizeof(double));
     Algorithm      *algo = NULL;
     Statistics     *stats = NULL;
-    Coords        **coords = NULL;
-    Coords         *avecoords = NULL;
-    Coords         *tcoords = NULL;
-    CoordsArray    *scratchA = NULL;
+    Cds        **cds = NULL;
+    Cds         *avecds = NULL;
+    Cds         *tcds = NULL;
+    CdsArray    *scratchA = NULL;
+
+    gsl_rng               *r2 = NULL;
+    const gsl_rng_type    *T = NULL;
+    T = gsl_rng_ranlxs2;
+    r2 = gsl_rng_alloc(T);
 
     /* setup scratchA */
-    scratchA = CoordsArrayInit();
-    CoordsArrayAlloc(scratchA, cnum, vlen);
-    CoordsArraySetup(scratchA);
+    scratchA = CdsArrayInit();
+    CdsArrayAlloc(scratchA, cnum, vlen);
+    CdsArraySetup(scratchA);
 
     baseA->scratchA = scratchA;
 
     /* duplicate baseA -- copy to scratchA */
-    CoordsArrayCopy(scratchA, baseA);
+    CdsArrayCopy(scratchA, baseA);
 
     /* setup local aliases based on scratchA */
     algo = scratchA->algo;
     stats = scratchA->stats;
-    coords = scratchA->coords;
-    avecoords = scratchA->avecoords;
-    tcoords = scratchA->tcoords;
+    cds = scratchA->cds;
+    avecds = scratchA->avecds;
+    tcds = scratchA->tcds;
 
     memcpy(scratchA->w, probs, vlen * sizeof(double));
     memcpy(baseA->w, probs, vlen * sizeof(double));
@@ -1468,7 +1427,7 @@ MultiPoseMix(CoordsArray *baseA, const double *probs, double *vars)
         printf("    Calculating distance matrix for embedding average ... \n");
         fflush(NULL);
 
-        CoordsCopyAll(avecoords, coords[0]);
+        CdsCopyAll(avecds, cds[0]);
         DistMatsAlloc(scratchA);
 
         if (algo->alignment == 1)
@@ -1479,24 +1438,25 @@ MultiPoseMix(CoordsArray *baseA, const double *probs, double *vars)
         printf("    Embedding average structure (ML) ... \n");
         fflush(NULL);
 
-        EmbedAveCoords(scratchA);
+        EmbedAveCds(scratchA);
 
         for (i = 0; i < vlen; ++i)
-            avecoords->resSeq[i] = i+1;
+            avecds->resSeq[i] = i+1;
 
         printf("    Finished embedding \n");
         fflush(NULL);
     }
     else
     {
-        slxn = (int) (genrand_real2() * cnum);
-        CoordsCopyAll(avecoords, baseA->coords[slxn]);
+        //slxn = (int) (genrand_real2() * cnum);
+        slxn = gsl_rng_uniform_int(r2, cnum);
+        CdsCopyAll(avecds, baseA->cds[slxn]);
     }
 
     if (algo->notrans == 0)
     {
-        CenMassWtIp(avecoords, scratchA->w);
-        ApplyCenterIp(avecoords);
+        CenMassWtIp(avecds, scratchA->w);
+        ApplyCenterIp(avecds);
     }
 
     /* The outer loop:
@@ -1518,16 +1478,14 @@ MultiPoseMix(CoordsArray *baseA, const double *probs, double *vars)
         ++round;
         baseA->algo->rounds = algo->rounds = round;
 
-        /* Find weighted center and translate all coords */
+        /* Find weighted center and translate all cds */
         CalcTranslations(scratchA, algo);
         for (i = 0; i < cnum; ++i)
-            ApplyCenterIp(coords[i]);
-
-        Mat3Cpy(lastmat, (const double **) scratchA->AxCovMat);
+            ApplyCenterIp(cds[i]);
 
         /* save the translation vector for each coord in the array */
         for (i = 0; i < cnum; ++i)
-            memcpy(coords[i]->translation, coords[i]->center, 3 * sizeof(double));
+            memcpy(cds[i]->translation, cds[i]->center, 3 * sizeof(double));
 
         /* when superimposing to an alignemnt, initially iterate into unwted LS for a few rounds */
         if (algo->alignment == 1 && round < 5)
@@ -1535,7 +1493,7 @@ MultiPoseMix(CoordsArray *baseA, const double *probs, double *vars)
 
         /* Inner loop:
            (1) Calc rotations given weights/weight matrices
-           (2) Rotate coords with new rotations
+           (2) Rotate cds with new rotations
            (3) Recalculate average
 
            Loops till convergence, holding constant the weights, variances, and covariances
@@ -1548,7 +1506,7 @@ MultiPoseMix(CoordsArray *baseA, const double *probs, double *vars)
 
             /* save the old rotation matrices to test convergence at bottom of loop */
             for (i = 0; i < cnum; ++i)
-                MatCpySym(coords[i]->last_matrix, (const double **) coords[i]->matrix, 3);
+                MatCpySym(cds[i]->last_matrix, (const double **) cds[i]->matrix, 3);
 
             /* find the optimal rotation matrices */
             if (algo->alignment == 1 /* && (round == 1 || cnum == 2) */)
@@ -1557,23 +1515,22 @@ MultiPoseMix(CoordsArray *baseA, const double *probs, double *vars)
                 deviation_sum = CalcRotations(scratchA);
 
             if (innerround == 1 &&
-                CheckConvergenceOuter(scratchA, round, algo->precision) == 1 &&
-                MatFrobNorm((const double **) lastmat, (const double **) scratchA->AxCovMat, 3, 3) < algo->precision)
+                CheckConvergenceOuter(scratchA, round, algo->precision) == 1)
                    goto outsidetheloops;
 
-            /* rotate the scratch coords with new rotation matrix */
+            /* rotate the scratch cds with new rotation matrix */
             for (i = 0; i < cnum; ++i)
-                RotateCoordsIp(coords[i], (const double **) coords[i]->matrix);
+                RotateCdsIp(cds[i], (const double **) cds[i]->matrix);
 
-            /* find global rmsd and average coords (both held in structure) */
+            /* find global rmsd and average cds (both held in structure) */
 			if (algo->alignment == 1)
 			{
-				AveCoordsOcc(scratchA);
-				EM_MissingCoords(scratchA);
+				AveCdsOcc(scratchA);
+				EM_MissingCds(scratchA);
 			}
 			else
 			{
-				AveCoords(scratchA);
+				AveCds(scratchA);
 			}
 
             stats->wRMSD_from_mean = sqrt(deviation_sum / (3 * vlen * cnum));
@@ -1602,13 +1559,15 @@ MultiPoseMix(CoordsArray *baseA, const double *probs, double *vars)
 /*     printf("\n    "); */
 /*     fflush(NULL); */
 
-    CoordsArrayCopy(baseA, scratchA);
+    CdsArrayCopy(baseA, scratchA);
     memcpy(vars, scratchA->var, vlen * sizeof(double));
     memcpy(vars, baseA->var, vlen * sizeof(double));
 
-    CoordsArrayDestroy(&scratchA);
+    CdsArrayDestroy(&scratchA);
     free(evals);
-    MatDestroy(&lastmat);
+
+    gsl_rng_free(r2);
+    r2 = NULL;
 
     return(round);
 }
@@ -1616,7 +1575,7 @@ MultiPoseMix(CoordsArray *baseA, const double *probs, double *vars)
 
 /* Calculates weights corresponding to the atomic, row-wise covariance matrix only */
 static void
-CalcWtsMix(CoordsArray *cdsA, const double *probs)
+CalcWtsMix(CdsArray *cdsA, const double *probs)
 {
     int             i;
     Algorithm      *algo = cdsA->algo;
@@ -1625,7 +1584,7 @@ CalcWtsMix(CoordsArray *cdsA, const double *probs)
     const int       vlen = cdsA->vlen;
 
     if (algo->noave == 0)
-        AveCoords(cdsA);
+        AveCds(cdsA);
 
     if (algo->leastsquares != 0)
     {
@@ -1642,7 +1601,6 @@ CalcWtsMix(CoordsArray *cdsA, const double *probs)
                 variance[i] = probs[i] * algo->constant;
 
         HierarchVars(cdsA);
-        LedoitWolfShrinkVar(cdsA, algo->LedoitWolf);
 
         for (i = 0; i < vlen; ++i)
         {
