@@ -27,24 +27,24 @@
 #define PCASTATS_SEEN
 
 void
-CalcPCA(CoordsArray *cdsA);
+CalcPCA(CdsArray *cdsA);
 
 void
-Calc3NPCA(CoordsArray *cdsA);
+Calc3NPCA(CdsArray *cdsA);
 
 void
-CalcStructPCA(CoordsArray *cdsA);
+CalcStructPCA(CdsArray *cdsA);
 
 void
-WritePCAFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile_root);
+WritePCAFile(PDBCdsArray *parray, CdsArray *cdsA, const char *outfile_root);
 
 void
-WriteModelPCAFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile_root);
+WriteModelPCAFile(PDBCdsArray *parray, CdsArray *cdsA, const char *outfile_root);
 
 void
-WritePCAMorphFile(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile_root);
+WritePCAMorphFile(PDBCdsArray *parray, CdsArray *cdsA, const char *outfile_root);
 
 void
-WritePCAProjections(PDBCoordsArray *parray, CoordsArray *cdsA, const char *outfile_root);
+WritePCAProjections(PDBCdsArray *parray, CdsArray *cdsA, const char *outfile_root);
 
 #endif
