@@ -1,3 +1,27 @@
+/*
+    Theseus - maximum likelihood superpositioning of macromolecular structures
+
+    Copyright (C) 2004-2010 Douglas L. Theobald
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the:
+
+    Free Software Foundation, Inc.,
+    59 Temple Place, Suite 330,
+    Boston, MA  02111-1307  USA
+
+    -/_|:|_|_\-
+*/
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
@@ -7,29 +31,23 @@
 #include "pdbUtils.h"
 #include "pdbStats.h"
 #include "CovMat.h"
-#include "lapack_dlt.h"
-#include "FragCoords.h"
+#include "FragCds.h"
 #include "ProcJacobiSVD.h"
 
-#if defined(__APPLE__)
-    #include <vecLib/clapack.h>
-    #include <vecLib/cblas.h>
-#endif
-
 static double
-CalcE0(const Coords *coords1, const Coords *coords2,
+CalcE0(const Cds *cds1, const Cds *cds2,
           const double *weights, const double *axesw);
 
 static double
-CalcE0Cov(const Coords *coords1, const Coords *coords2,
+CalcE0Cov(const Cds *cds1, const Cds *cds2,
              const double *axesw);
 
 static void
-CalcR(const Coords *coords1, const Coords *coords2, double **Rmat,
+CalcR(const Cds *cds1, const Cds *cds2, double **Rmat,
          const double *weights, const double *axesw);
 
 static void
-CalcRCov(const Coords *coords1, const Coords *coords2, double **Rmat,
+CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat,
             const double **covmat, const double *axesw);
 
 static int
@@ -39,25 +57,25 @@ static int
 CalcRotMat(double **rotmat, double **Umat, double **VTmat);
 
 static double
-CalcE0(const Coords *coords1, const Coords *coords2,
+CalcE0(const Cds *cds1, const Cds *cds2,
          const double *weights, const double *axesw)
 {   
     int             i;
     double          sum;
-    const double   *x1 = (const double *) coords1->x,
-                   *y1 = (const double *) coords1->y,
-                   *z1 = (const double *) coords1->z;
-    const double   *x2 = (const double *) coords2->x,
-                   *y2 = (const double *) coords2->y,
-                   *z2 = (const double *) coords2->z;
+    const double   *x1 = (const double *) cds1->x,
+                   *y1 = (const double *) cds1->y,
+                   *z1 = (const double *) cds1->z;
+    const double   *x2 = (const double *) cds2->x,
+                   *y2 = (const double *) cds2->y,
+                   *z2 = (const double *) cds2->z;
     double          x1i, y1i, z1i, x2i, y2i, z2i;
     const double    axeswx = axesw[0], axeswy = axesw[1], axeswz = axesw[2];
 /* #include "pdbIO.h" */
-/* PrintCoords((Coords *)coords1); */
-/* PrintCoords((Coords *)coords2); */
+/* PrintCds((Cds *)cds1); */
+/* PrintCds((Cds *)cds2); */
 
     sum = 0.0;
-    i = coords1->vlen;
+    i = cds1->vlen;
     while(i-- > 0)
     {
         x1i = *x1++;
@@ -78,29 +96,29 @@ CalcE0(const Coords *coords1, const Coords *coords2,
 
 
 static double
-CalcE0Cov(const Coords *coords1, const Coords *coords2,
+CalcE0Cov(const Cds *cds1, const Cds *cds2,
              const double *axesw)
 {   
     int             i;
     double          sum;
-    const double   *x2 = (const double *) coords2->x,
-                   *y2 = (const double *) coords2->y,
-                   *z2 = (const double *) coords2->z;
-    const double   *x1 = (const double *) coords1->x,
-                   *y1 = (const double *) coords1->y,
-                   *z1 = (const double *) coords1->z;
-    const double   *cx2 = (const double *) coords2->covx,
-                   *cy2 = (const double *) coords2->covy,
-                   *cz2 = (const double *) coords2->covz;
-    const double   *cx1 = (const double *) coords1->covx,
-                   *cy1 = (const double *) coords1->covy,
-                   *cz1 = (const double *) coords1->covz;
+    const double   *x2 = (const double *) cds2->x,
+                   *y2 = (const double *) cds2->y,
+                   *z2 = (const double *) cds2->z;
+    const double   *x1 = (const double *) cds1->x,
+                   *y1 = (const double *) cds1->y,
+                   *z1 = (const double *) cds1->z;
+    const double   *cx2 = (const double *) cds2->covx,
+                   *cy2 = (const double *) cds2->covy,
+                   *cz2 = (const double *) cds2->covz;
+    const double   *cx1 = (const double *) cds1->covx,
+                   *cy1 = (const double *) cds1->covy,
+                   *cz1 = (const double *) cds1->covz;
     double          x1i, y1i, z1i, x2i, y2i, z2i,
                     cx1i, cy1i, cz1i, cx2i, cy2i, cz2i;
     const double    axeswx = axesw[0], axeswy = axesw[1], axeswz = axesw[2];
 
     sum = 0.0;
-    i = coords1->vlen;
+    i = cds1->vlen;
     while(i-- > 0)
     {
         x1i = *x1++;
@@ -129,17 +147,17 @@ CalcE0Cov(const Coords *coords1, const Coords *coords2,
 /* This function assumes that the coordinates have been centered previously
    Use CenMass() and ApplyCenter() */
 static void
-CalcR(const Coords *coords1, const Coords *coords2, double **Rmat,
+CalcR(const Cds *cds1, const Cds *cds2, double **Rmat,
          const double *weights, const double *axesw)
 {
     int             i;
     double          weight;
-    const double   *x2 = (const double *) coords2->x,
-                   *y2 = (const double *) coords2->y,
-                   *z2 = (const double *) coords2->z;
-    const double   *x1 = (const double *) coords1->x,
-                   *y1 = (const double *) coords1->y,
-                   *z1 = (const double *) coords1->z;
+    const double   *x2 = (const double *) cds2->x,
+                   *y2 = (const double *) cds2->y,
+                   *z2 = (const double *) cds2->z;
+    const double   *x1 = (const double *) cds1->x,
+                   *y1 = (const double *) cds1->y,
+                   *z1 = (const double *) cds1->z;
     const double    axeswx = sqrt(axesw[0]),
                     axeswy = sqrt(axesw[1]),
                     axeswz = sqrt(axesw[2]);
@@ -153,7 +171,7 @@ CalcR(const Coords *coords1, const Coords *coords2, double **Rmat,
 
    /*  printf("\n axes weights: %f %f %f ", axeswx, axeswy, axeswz); */
 
-    i = coords1->vlen;
+    i = cds1->vlen;
     while(i-- > 0)
     {
         weight = *weights++;
@@ -192,15 +210,15 @@ CalcR(const Coords *coords1, const Coords *coords2, double **Rmat,
 
 
 static void
-CalcRvan(const Coords *coords1, const Coords *coords2, double **Rmat)
+CalcRvan(const Cds *cds1, const Cds *cds2, double **Rmat)
 {
     int             i;
-    const double   *x1 = (const double *) coords1->x,
-                   *y1 = (const double *) coords1->y,
-                   *z1 = (const double *) coords1->z;
-    const double   *x2 = (const double *) coords2->x,
-                   *y2 = (const double *) coords2->y,
-                   *z2 = (const double *) coords2->z;
+    const double   *x1 = (const double *) cds1->x,
+                   *y1 = (const double *) cds1->y,
+                   *z1 = (const double *) cds1->z;
+    const double   *x2 = (const double *) cds2->x,
+                   *y2 = (const double *) cds2->y,
+                   *z2 = (const double *) cds2->z;
     double          x2i, y2i, z2i, x1i, y1i, z1i;
     double          Rmat00, Rmat01, Rmat02,
                     Rmat10, Rmat11, Rmat12,
@@ -211,7 +229,7 @@ CalcRvan(const Coords *coords1, const Coords *coords2, double **Rmat)
     Rmat00 = Rmat01 = Rmat02 = Rmat10 = Rmat11 = Rmat12 =
     Rmat20 = Rmat21 = Rmat22 = 0.0;
 
-    i = coords1->vlen;
+    i = cds1->vlen;
     while(i-- > 0)
     {
         x1i = *x1++;
@@ -248,15 +266,15 @@ CalcRvan(const Coords *coords1, const Coords *coords2, double **Rmat)
 
 
 static void
-CalcRFrag(const FragCoords *coords1, const FragCoords *coords2, double **Rmat)
+CalcRFrag(const FragCds *cds1, const FragCds *cds2, double **Rmat)
 {
     int             i;
-    const double   *x1 = (const double *) coords1->x,
-                   *y1 = (const double *) coords1->y,
-                   *z1 = (const double *) coords1->z;
-    const double   *x2 = (const double *) coords2->x,
-                   *y2 = (const double *) coords2->y,
-                   *z2 = (const double *) coords2->z;
+    const double   *x1 = (const double *) cds1->x,
+                   *y1 = (const double *) cds1->y,
+                   *z1 = (const double *) cds1->z;
+    const double   *x2 = (const double *) cds2->x,
+                   *y2 = (const double *) cds2->y,
+                   *z2 = (const double *) cds2->z;
     double          x2i, y2i, z2i, x1i, y1i, z1i;
     double          Rmat00, Rmat01, Rmat02,
                     Rmat10, Rmat11, Rmat12,
@@ -267,7 +285,7 @@ CalcRFrag(const FragCoords *coords1, const FragCoords *coords2, double **Rmat)
     Rmat00 = Rmat01 = Rmat02 = Rmat10 = Rmat11 = Rmat12 =
     Rmat20 = Rmat21 = Rmat22 = 0.0;
 
-    i = coords1->fraglen;
+    i = cds1->fraglen;
     while(i-- > 0)
     {
         x1i = *x1++;
@@ -304,16 +322,16 @@ CalcRFrag(const FragCoords *coords1, const FragCoords *coords2, double **Rmat)
 
 
 static void
-CalcRCov(const Coords *coords1, const Coords *coords2, double **Rmat,
+CalcRCov(const Cds *cds1, const Cds *cds2, double **Rmat,
             const double **covmat, const double *axesw)
 {
     int             i;
-    const double   *x2 = (const double *) coords2->covx,
-                   *y2 = (const double *) coords2->covy,
-                   *z2 = (const double *) coords2->covz;
-    const double   *x1 = (const double *) coords1->x,
-                   *y1 = (const double *) coords1->y,
-                   *z1 = (const double *) coords1->z;
+    const double   *x2 = (const double *) cds2->covx,
+                   *y2 = (const double *) cds2->covy,
+                   *z2 = (const double *) cds2->covz;
+    const double   *x1 = (const double *) cds1->x,
+                   *y1 = (const double *) cds1->y,
+                   *z1 = (const double *) cds1->z;
     const double    axeswx = sqrt(axesw[0]),
                     axeswy = sqrt(axesw[1]),
                     axeswz = sqrt(axesw[2]);
@@ -327,7 +345,7 @@ CalcRCov(const Coords *coords1, const Coords *coords2, double **Rmat,
 
    /*  printf("\n axes weights: %f %f %f ", axeswx, axeswy, axeswz); */
 
-    i = coords1->vlen;
+    i = cds1->vlen;
     while(i-- > 0)
     {
         x2i = axeswx * *x2++;
@@ -739,15 +757,15 @@ CalcRotMat(double **rotmat, double **Umat, double **Vtmat)
 /* returns sum of squared residuals, E
    rmsd = sqrt(E/atom_num)  */
 double
-ProcJacobiSVD(const Coords *coords1, const Coords *coords2, double **rotmat,
+ProcJacobiSVD(const Cds *cds1, const Cds *cds2, double **rotmat,
                  const double *weights, const double *axesw,
                  double **Rmat, double **Umat, double **VTmat, double *sigma)
 {
     double          det, sumdev;
 
-    sumdev = CalcE0(coords1, coords2, weights, axesw);
+    sumdev = CalcE0(cds1, cds2, weights, axesw);
     /* printf("\n # sumdev = %8.2f ", sumdev); */
-    CalcR(coords1, coords2, Rmat, weights, axesw);
+    CalcR(cds1, cds2, Rmat, weights, axesw);
     CalcJacobiSVD(Rmat, Umat, sigma, VTmat, 1e-8);
     det = CalcRotMat(rotmat, Umat, VTmat);
 
@@ -775,17 +793,17 @@ ProcJacobiSVD(const Coords *coords1, const Coords *coords2, double **rotmat,
 
 
 // static double
-// CalcInnProdNorm(const Coords *coords)
+// CalcInnProdNorm(const Cds *cds)
 // {   
 //     int             i;
 //     double          sum;
-//     const double   *x = (const double *) coords->x,
-//                    *y = (const double *) coords->y,
-//                    *z = (const double *) coords->z;
+//     const double   *x = (const double *) cds->x,
+//                    *y = (const double *) cds->y,
+//                    *z = (const double *) cds->z;
 //     double          xi, yi, zi;
 // 
 //     sum = 0.0;
-//     i = coords->vlen;
+//     i = cds->vlen;
 //     while(i-- > 0)
 //     {
 //         xi = *x++;
@@ -800,20 +818,20 @@ ProcJacobiSVD(const Coords *coords1, const Coords *coords2, double **rotmat,
 // 
 // 
 // static double
-// CalcInnProdNormRot(const Coords *coords, const double **rmat)
+// CalcInnProdNormRot(const Cds *cds, const double **rmat)
 // {   
 //     int             i;
 //     double          sum;
-//     const double   *x = (const double *) coords->x,
-//                    *y = (const double *) coords->y,
-//                    *z = (const double *) coords->z;
+//     const double   *x = (const double *) cds->x,
+//                    *y = (const double *) cds->y,
+//                    *z = (const double *) cds->z;
 //     double          xi, yi, zi, xir, yir, zir;
 //     const double    rmat00 = rmat[0][0], rmat01 = rmat[0][1], rmat02 = rmat[0][2],
 //                     rmat10 = rmat[1][0], rmat11 = rmat[1][1], rmat12 = rmat[1][2],
 //                     rmat20 = rmat[2][0], rmat21 = rmat[2][1], rmat22 = rmat[2][2];
 // 
 //     sum = 0.0;
-//     i = coords->vlen;
+//     i = cds->vlen;
 //     while(i-- > 0)
 //     {
 //         xi = *x++;
@@ -832,16 +850,16 @@ ProcJacobiSVD(const Coords *coords1, const Coords *coords2, double **rotmat,
 
 
 double
-ProcJacobiSVDvan(const Coords *coords1, const Coords *coords2, double **rotmat,
+ProcJacobiSVDvan(const Cds *cds1, const Cds *cds2, double **rotmat,
                  double **Rmat, double **Umat, double **VTmat, double *sigma)
 {
     double          det, sumdev, term1, term2;
 
-    // term1 = CalcInnProdNorm(coords2);
-    CalcRvan(coords1, coords2, Rmat);
+    // term1 = CalcInnProdNorm(cds2);
+    CalcRvan(cds1, cds2, Rmat);
     CalcJacobiSVD(Rmat, Umat, sigma, VTmat, 1e-12);
     det = CalcRotMat(rotmat, Umat, VTmat);
-    // term2 = CalcInnProdNormRot(coords1, (const double **) rotmat);
+    // term2 = CalcInnProdNormRot(cds1, (const double **) rotmat);
     term1 = term2 = 0.0; /* this is just a fudge to make this faster - DLT */
     sumdev = term1 + term2;
 
@@ -870,12 +888,12 @@ ProcJacobiSVDvan(const Coords *coords1, const Coords *coords2, double **rotmat,
 
 
 double
-ProcJacobiSVDFrag(const FragCoords *coords1, const FragCoords *coords2, double **rotmat,
+ProcJacobiSVDFrag(const FragCds *cds1, const FragCds *cds2, double **rotmat,
                   double **Rmat, double **Umat, double **VTmat, double *sigma)
 {
     double          det, sumdev, term1, term2;
 
-    CalcRFrag(coords1, coords2, Rmat);
+    CalcRFrag(cds1, cds2, Rmat);
     CalcJacobiSVD(Rmat, Umat, sigma, VTmat, 1e-12);
     det = CalcRotMat(rotmat, Umat, VTmat);
     term1 = term2 = 0.0; /* this is just a fudge to make this faster - DLT */
@@ -893,17 +911,17 @@ ProcJacobiSVDFrag(const FragCoords *coords1, const FragCoords *coords2, double *
 /* returns sum of squared residuals, E
    rmsd = sqrt(E/atom_num)  */
 double
-ProcJacobiSVDCov(Coords *coords1, Coords *coords2, double **rotmat,
+ProcJacobiSVDCov(Cds *cds1, Cds *cds2, double **rotmat,
                     const double **covmat, const double *axesw, double **Rmat,
                     double **Umat, double **VTmat, double *sigma)
 {
     double          det, sumdev = 0.0;
 
-    CalcCovCoords(coords1, covmat);
-    CalcCovCoords(coords2, covmat);
+    CalcCovCds(cds1, covmat);
+    CalcCovCds(cds2, covmat);
 
-    sumdev = CalcE0Cov(coords1, coords2, axesw);
-    CalcRCov(coords1, coords2, Rmat, covmat, axesw);
+    sumdev = CalcE0Cov(cds1, cds2, axesw);
+    CalcRCov(cds1, cds2, Rmat, covmat, axesw);
     CalcJacobiSVD(Rmat, Umat, sigma, VTmat, DBL_EPSILON);
     det = CalcRotMat(rotmat, Umat, VTmat);
 
