@@ -33,10 +33,8 @@
 #include "pdbIO.h"
 #include "Embed.h"
 #include "DLTmath.h"
-#include "FragCoords.h"
-#include "ProcLAPACKSVD.h"
-#include "Kabsch.h"
-//#include "quartic2.h"
+#include "FragCds.h"
+#include "ProcGSLSVD.h"
 #include "QuarticHornFrag.h"
 
 
@@ -175,7 +173,7 @@ horn_root(double *coeff, double guess, int n, double delta)
 
 
 void
-ComputeQuartHornFrag(const FragCoords *frag1, const FragCoords *frag2, double *coeff)
+ComputeQuartHornFrag(const FragCds *frag1, const FragCds *frag2, double *coeff)
 {
     double          Sxx, Sxy, Sxz,
                     Syx, Syy, Syz,
@@ -243,7 +241,7 @@ ComputeQuartHornFrag(const FragCoords *frag1, const FragCoords *frag2, double *c
 /* A lot of register variables, but this sort of thing scales very well with
    new and improved processors */
 double
-CalcQuarticCoeffsPu2(const FragCoords *frag1, const FragCoords *frag2, const int len, double *coeff, const double innerprod, double *quat)
+CalcQuarticCoeffsPu2(const FragCds *frag1, const FragCds *frag2, const int len, double *coeff, const double innerprod, double *quat)
 {
     double          Sxx, Sxy, Sxz, Syx, Syy, Syz, Szx, Szy, Szz;
     double          Szz2, Syy2, Sxx2, Sxy2, Syz2, Sxz2, Syx2, Szy2, Szx2,
@@ -367,7 +365,7 @@ CalcQuarticCoeffsPu2(const FragCoords *frag1, const FragCoords *frag2, const int
    It goes through all four rows if necessary to find one that is large enough to avoid floating 
    point error. */
 static double
-CalcQuarticCoeffsPu(const FragCoords *frag1, const FragCoords *frag2, const int len, double *coeff, const double innerprod, double *quat)
+CalcQuarticCoeffsPu(const FragCds *frag1, const FragCds *frag2, const int len, double *coeff, const double innerprod, double *quat)
 {
     double          Sxx, Sxy, Sxz, Syx, Syy, Syz, Szx, Szy, Szz;
     double          Szz2, Syy2, Sxx2, Sxy2, Syz2, Sxz2, Syx2, Szy2, Szx2,
@@ -593,7 +591,7 @@ RotMatToQuaternion(const double **rot, double *quat)
 /* returns the sum of the deviations
    rmsd = sqrt(sum_dev/atom_num) */
 double
-QuarticHornFrag(const FragCoords *frag1, const FragCoords *frag2, double *coeff)
+QuarticHornFrag(const FragCds *frag1, const FragCds *frag2, double *coeff)
 {
     double          frag1_radgyr;
     double          frag2_radgyr;
@@ -617,7 +615,7 @@ QuarticHornFrag(const FragCoords *frag1, const FragCoords *frag2, double *coeff)
     double        *sigma = malloc(3 * sizeof(double));
     double        **rotmat2 = MatAlloc(3, 3);
 
-    ProcLAPACKSVDFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
+    ProcGSLSVDFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
 
     RotMatToQuaternion((const double **) rotmat2, quat);
     printf("\n% -14.6e % -14.6e % -14.6e % -14.6e", quat[0], quat[1], quat[2], quat[3]);
@@ -643,14 +641,14 @@ QuarticHornFrag(const FragCoords *frag1, const FragCoords *frag2, double *coeff)
 }
 
 
-#include "FragCoords.h"
+#include "FragCds.h"
 
 void
-FragDistPu(CoordsArray *cdsA, int fraglen, int center_ca, int pu)
+FragDistPu(CdsArray *cdsA, int fraglen, int center_ca, int pu)
 {
     int             coord1, coord2;
     int             i, k, offset, tmp, num, count;
-    FragCoords     *frag1 = NULL, *frag2 = NULL;
+    FragCds     *frag1 = NULL, *frag2 = NULL;
     double         *coeff = NULL;
     double          var;
     FILE           *distfile = NULL, *distfile2 = NULL;
@@ -677,8 +675,8 @@ FragDistPu(CoordsArray *cdsA, int fraglen, int center_ca, int pu)
     distfile2 = fopen("frags_dist2.txt", "w");
     coeff = (double *) calloc(5, sizeof(double));
 
-    frag1 = FragCoordsAlloc(fraglen);
-    frag2 = FragCoordsAlloc(fraglen);
+    frag1 = FragCdsAlloc(fraglen);
+    frag2 = FragCdsAlloc(fraglen);
 
     offset = (fraglen - 1) / 2;
 
@@ -700,13 +698,13 @@ FragDistPu(CoordsArray *cdsA, int fraglen, int center_ca, int pu)
                 {
                     tmp = i + k - offset;
 
-                    frag1->x[k] = cdsA->coords[coord1]->x[tmp];
-                    frag1->y[k] = cdsA->coords[coord1]->y[tmp];
-                    frag1->z[k] = cdsA->coords[coord1]->z[tmp];
+                    frag1->x[k] = cdsA->cds[coord1]->x[tmp];
+                    frag1->y[k] = cdsA->cds[coord1]->y[tmp];
+                    frag1->z[k] = cdsA->cds[coord1]->z[tmp];
     
-                    frag2->x[k] = cdsA->coords[coord2]->x[tmp];
-                    frag2->y[k] = cdsA->coords[coord2]->y[tmp];
-                    frag2->z[k] = cdsA->coords[coord2]->z[tmp];
+                    frag2->x[k] = cdsA->cds[coord2]->x[tmp];
+                    frag2->y[k] = cdsA->cds[coord2]->y[tmp];
+                    frag2->z[k] = cdsA->cds[coord2]->z[tmp];
                 }
 
                 if (center_ca == 1)
@@ -720,7 +718,7 @@ FragDistPu(CoordsArray *cdsA, int fraglen, int center_ca, int pu)
                     CenterFrag(frag2);
                 }
 
-                //var = QuarticHornFrag((const FragCoords *) frag1, (const FragCoords *) frag2, coeff);
+                //var = QuarticHornFrag((const FragCds *) frag1, (const FragCds *) frag2, coeff);
 
                 if (pu == 1)
                 {
@@ -728,7 +726,8 @@ FragDistPu(CoordsArray *cdsA, int fraglen, int center_ca, int pu)
 					frag2_radgyr = RadGyrSqrFrag(frag2);
 					lambdamax = CalcQuarticCoeffsPu(frag1, frag2, frag1->fraglen, coeff, frag1_radgyr + frag2_radgyr, quat);
 					rmsd2 = (frag1_radgyr + frag2_radgyr) - (2.0 * lambdamax);
-					var = KabschFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
+					//var = KabschFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
+					var = ProcGSLSVDFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
 					printf("\nQCP rmsd = %e %e\n", sqrt(rmsd2/fraglen), sqrt(var/fraglen));
 					QuatToRotmat(rotmat, quat);
  				}
@@ -737,8 +736,8 @@ FragDistPu(CoordsArray *cdsA, int fraglen, int center_ca, int pu)
 	//				printf("\n% -14.6e % -14.6e % -14.6e % -14.6e", quat[0], quat[1], quat[2], quat[3]);
 	// 				Mat3Print(rotmat);
 	
-					//var = ProcLAPACKSVDFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
-					var = KabschFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
+					var = ProcGSLSVDFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
+					//var = KabschFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
 					//var = ProcJacobiSVDFrag(frag1, frag2, rotmat2, Rmat, Umat, VTmat, sigma);
 					//RotMatToQuaternion((const double **) rotmat2, quat);
 	
@@ -779,8 +778,8 @@ FragDistPu(CoordsArray *cdsA, int fraglen, int center_ca, int pu)
 	free(sigma);
 	free(quat);
 
-    FragCoordsFree(&frag1);
-    FragCoordsFree(&frag2);
+    FragCdsFree(&frag1);
+    FragCdsFree(&frag2);
     free(coeff);
     fclose(distfile);
     fclose(distfile2);
