@@ -39,21 +39,24 @@
 #include <time.h>
 #include <gsl/gsl_rng.h>
 #include <gsl/gsl_randist.h>
+#include <gsl/gsl_sort.h>
+#include <gsl/gsl_statistics_double.h>
 
 #include "distfit_local.h"
 
-#define VERSION "0.87"
-#define DISTNUM 22
+#define VERSION "0.90"
+#define DISTNUM 23
 
 /* array of function names */
 char
 dist_name[DISTNUM][32] = 
 {
 	"Normal",      "Laplace",   "EVD",        "Logistic",
-	"Cauchy",      "Uniform",   "Weibull",
+	"Cauchy",      "Uniform",   "Weibull", 
 	"Gamma",       "ChisqrGen",  "Lognormal",
 	"Invgamma",    "Invgauss",  "Recinvgauss", "Pareto",
 	"Exponential", "Invchisqr", "Chisqr",      "Chi",
+	"Rayleigh",
 	"Maxwell",     "Beta",      "BetaSym", "BetaPrime"     //"Binomial"
 };
 
@@ -62,10 +65,11 @@ DistFit
 distfit_func[DISTNUM] = 
 {
 	&normal_fit,    &laplace_fit,   &EVD_fit,         &logistic_fit,
-	&cauchy_fit,    &uniform_fit,   &weibull_fit,
+	&cauchy_fit,    &uniform_fit,   &weibull_fit, 
 	&gamma_fit,     &chisqrgen_fit,   &lognormal_fit,
 	&invgamma_fit,  &invgauss_fit,  &recinvgauss_fit, &pareto_fit,
 	&exp_fit,       &invchisqr_fit, &chisqr_fit,      &chi_fit,
+	&rayleigh_fit,
 	&maxwell_fit,   &beta_fit,      &betasym_fit,  &betaprime_fit   //&binomial_fit
 };
 
@@ -78,6 +82,7 @@ distdev_func[DISTNUM] =
 	&gamma_dev,     &chisqrgen_dev, &lognormal_dev,
 	&invgamma_dev,  &invgauss_dev,  &recinvgauss_dev, &pareto_dev,
 	&exp_dev,       &invchisqr_dev, &chisqr_dev,      &chi_dev,
+	&rayleigh_dev,
 	&maxwell_dev,   &beta_dev,      &betasym_dev,     &betaprime_dev //&binomial_dev
 };
 
@@ -89,6 +94,7 @@ distpdf_func[DISTNUM] =
 	&gamma_pdf,     &chisqrgen_pdf,   &lognormal_pdf,
 	&invgamma_pdf,  &invgauss_pdf,  &recinvgauss_pdf, &pareto_pdf,
 	&exp_pdf,       &invchisqr_pdf, &chisqr_pdf,      &chi_pdf,
+	&rayleigh_pdf,
 	&maxwell_pdf,   &beta_pdf,      &betasym_pdf,     &betaprime_pdf //&binomial_pdf
 };
 
@@ -100,6 +106,7 @@ distcdf_func[DISTNUM] =
 	&gamma_cdf,     &chisqrgen_cdf,   &lognormal_cdf,
 	&invgamma_cdf,  &invgauss_cdf,  &recinvgauss_cdf, &pareto_cdf,
 	&exp_cdf,       &invchisqr_cdf, &chisqr_cdf,      &chi_cdf,
+	&rayleigh_cdf,
 	&maxwell_cdf,   &beta_cdf,      &betasym_cdf,     &betaprime_cdf //&binomial_cdf
 };
 
@@ -111,6 +118,7 @@ distsdf_func[DISTNUM] =
 	&gamma_sdf,     &chisqrgen_sdf,   &lognormal_sdf,
 	&invgamma_sdf,  &invgauss_sdf,  &recinvgauss_sdf, &pareto_sdf,
 	&exp_sdf,       &invchisqr_sdf, &chisqr_sdf,      &chi_sdf,
+	&rayleigh_sdf,
 	&maxwell_sdf,   &beta_sdf,      &betasym_sdf,     &betaprime_sdf //&binomial_sdf
 };
 
@@ -122,6 +130,7 @@ distint_func[DISTNUM] =
 	&gamma_int,     &chisqrgen_int,   &lognormal_int,
 	&invgamma_int,  &invgauss_int,  &recinvgauss_int, &pareto_int,
 	&exp_int,       &invchisqr_int, &chisqr_int,      &chi_int,
+	&rayleigh_int,
 	&maxwell_int,   &beta_int,      &betasym_int,     &betaprime_int //&binomial_int
 };
 
@@ -133,6 +142,7 @@ dist_pnum[DISTNUM] =
 	2, 2, 2,
 	2, 2, 2, 2,
 	1, 1, 1, 1,
+	1,
 	1, 2, 1, 2 //2
 };
 
@@ -145,6 +155,7 @@ dist_nonneg[DISTNUM] =
 	1, 1, 0,
 	0, 0, 0, 0,
 	1, 0, 1, 1,
+	1,
 	1, 0, 0, 1 //1
 };
 
@@ -157,6 +168,7 @@ dist_posdef[DISTNUM] =
 	0, 0, 1,
 	1, 1, 1, 1,
 	0, 1, 0, 0,
+	0,
 	0, 0, 0, 0 //0
 };
 
@@ -168,6 +180,7 @@ dist_beta[DISTNUM] =
 	0, 0, 0,
 	0, 0, 0, 0,
 	0, 0, 0, 0,
+	0,
 	0, 1, 1, 0 //0
 };
 
@@ -181,6 +194,84 @@ double *sdfparams = NULL;
 double *intparams = NULL;
 
 
+double
+FindMode(const double *x, const int len)
+{
+    int     i;
+    int     i_beg, i_end, i_min, intsize;
+    double  range, range_min, mode;
+
+
+    i_min = i_beg = 0;
+    i_end = len -1;
+    range_min = 0.0;
+
+    intsize = (i_end - i_beg) / 2.0;
+
+    while (intsize > 1)
+    {
+        for (i = i_beg; i < i_end - intsize; ++i)
+        {
+            range = x[i + intsize] - x[i];
+
+            if (i == i_beg)
+            {
+                i_min = i_beg;
+                range_min = range;
+            }
+            else if (range < range_min)
+            {
+                i_min = i;
+                range_min = range;
+            }
+        }
+
+        i_beg = i_min;
+        i_end = i_min + intsize;
+        intsize = (i_end - i_beg) / 2.0;
+    }
+
+    if (intsize == 1)
+        mode = (x[i_end] + x[i_beg]) / 2.0;
+    else
+        mode = x[i_beg];
+
+    return(mode);
+}
+
+
+void
+CalcDistStats(const double *array, const int len)
+{
+    double        *x = malloc(len * sizeof(double));
+    double         pstats[10];
+
+    memcpy(x, array, len * sizeof(double));
+
+    gsl_sort(x, 1, len);
+    pstats[0] = gsl_stats_mean(x, 1, len);
+    pstats[1] = gsl_stats_sd_with_fixed_mean(x, 1, len, pstats[0]);
+    pstats[2] = gsl_stats_skew_m_sd(x, 1, len, pstats[0], pstats[1]);
+    pstats[3] = gsl_stats_kurtosis_m_sd(x, 1, len, pstats[0], pstats[1]);
+    pstats[4] = gsl_stats_median_from_sorted_data(x, 1, len);
+    pstats[5] = gsl_stats_quantile_from_sorted_data(x, 1, len, 0.025);
+    pstats[6] = gsl_stats_quantile_from_sorted_data(x, 1, len, 0.975);
+    pstats[7] = gsl_stats_quantile_from_sorted_data(x, 1, len, 0.05);
+    pstats[8] = gsl_stats_quantile_from_sorted_data(x, 1, len, 0.95);
+    pstats[9] = FindMode(x, len);
+    
+    printf("\nmode approximation: %g\n", pstats[9]);
+
+    printf("\n       ave (+/-       SD)    skew    kurt     median ( 95%% credible interval ) ( 90%% credible interval )");
+    printf("\n--------------------------------------------------------------------------------------------------------");
+
+    printf("\n% 10.2f (+/- %8.2f) % 7.2f % 7.2f % 10.2f (% 10.2f - % 10.2f) (% 10.2f - % 10.2f)\n\n", 
+           pstats[0], pstats[1], pstats[2], pstats[3], pstats[4], pstats[5], pstats[6], pstats[7], pstats[8]);
+
+    free(x);
+}
+
+
 int
 ParseCmdLine(int *argc, char **argv[])
 {
@@ -198,7 +289,7 @@ ParseCmdLine(int *argc, char **argv[])
             case 'c':
                 dfparams->col = (int) strtol(optarg, NULL, 10) - 1;
 
-                if (dfparams->col > 11)
+                if (dfparams->col > 15)
                 {
                     Usage();
                     exit(EXIT_FAILURE);
@@ -259,16 +350,18 @@ ParseCmdLine(int *argc, char **argv[])
                         dfparams->distindex = 15;
                     else if (strncmp(optarg, "chisqr", 4) == 0)
                         dfparams->distindex = 16;
-                    else if (strncmp(optarg, "chi", 3) == 0)
+                    else if (strncmp(optarg, "chi", 4) == 0)
                         dfparams->distindex = 17;
-                    else if (strncmp(optarg, "maxwell", 3) == 0)
+                    else if (strncmp(optarg, "rayleigh", 3) == 0)
                         dfparams->distindex = 18;
-                    else if (strncmp(optarg, "beta", 4) == 0)
+                    else if (strncmp(optarg, "maxwell", 3) == 0)
                         dfparams->distindex = 19;
-                    else if (strncmp(optarg, "betasym", 4) == 0)
+                    else if (strncmp(optarg, "beta", 4) == 0)
                         dfparams->distindex = 20;
-                    else if (strncmp(optarg, "betaprime", 4) == 0)
+                    else if (strncmp(optarg, "betasym", 4) == 0)
                         dfparams->distindex = 21;
+                    else if (strncmp(optarg, "betaprime", 4) == 0)
+                        dfparams->distindex = 22;
                     else
                     {
                         printf("\n  Bad -d \"%s\" \n", optarg);
@@ -373,7 +466,7 @@ main(int argc, char *argv[])
     dfparams->seed = -1;
     dfparams->p1 = 1.0;
     dfparams->p2 = 1.0;
-    dfparams->distdev = 0;
+    dfparams->distdev = -1;
     dfparams->randnum = 100;
     dfparams->mix = 0;
     dfparams->fixzeros = 0;
@@ -389,6 +482,9 @@ main(int argc, char *argv[])
 
     narguments = ParseCmdLine(&argc, &argv);
 
+    if (dfparams->seed == -1)
+        dfparams->seed = (unsigned long) time(NULL);
+
     if (pdfparams != NULL)
     {
         if (dfparams->distindex == -1)
@@ -441,6 +537,11 @@ main(int argc, char *argv[])
         free(intparams);
         exit(EXIT_SUCCESS);
     }
+    else if (dfparams->distdev > -1)
+    {
+        PrintRandDist("tmpdist.txt", distdev_func[dfparams->distdev], dfparams->p1, dfparams->p2, dfparams->randnum, dfparams->seed);
+        exit(EXIT_SUCCESS);
+    }
 
     if (narguments == 1)
     {
@@ -515,7 +616,7 @@ main(int argc, char *argv[])
     }
     else
     {
-        fprintf(stderr, "\n ERROR: Distribution file unspecified \n\n");
+        fprintf(stderr, "\n ERROR00: Distribution file unspecified \n\n");
         Usage();
         exit(EXIT_FAILURE);
     }
@@ -543,10 +644,7 @@ main(int argc, char *argv[])
         diststats[0]->distfit_func = distfit_func[dfparams->distindex];
     }
 
-    if (dfparams->seed == -1)
-        dfparams->seed = (unsigned long) time(NULL);
-
-    PrintRandDist("tmpdist.txt", distdev_func[dfparams->distdev], dfparams->p1, dfparams->p2, dfparams->randnum, dfparams->seed);
+    //PrintRandDist("tmpdist.txt", distdev_func[dfparams->distdev], dfparams->p1, dfparams->p2, dfparams->randnum, dfparams->seed);
 
     moments(array, length, &ave, &median, &adev, &mdev, &sdev, &var, &skew, &kurt, &hrange, &lrange);
 
@@ -558,6 +656,8 @@ main(int argc, char *argv[])
     printf("-------------------------- \n");
     printf("% 11.3e to % 11.3e\n\n", lrange, hrange);
 
+    CalcDistStats(array, length);
+
     if (dfparams->mix > 0)
     {
         double     *mean = malloc(dfparams->mix * sizeof(double));
@@ -820,21 +920,29 @@ void
 BootFit(DistStats **diststats, int distindex, double *array, int length, DFParams *dfparams)
 {
     int             i, j, k, m, bootstrap = dfparams->bootstrap;
-    double         *weights = NULL, *jackarray = NULL;
+    double         *jackarray = NULL, *p = NULL;
+    unsigned int   *weights = NULL;
     double          param1, param2, chisq, logL, AIC, BIC;
     double          param1_2, param2_2, logL_2, AIC_2, BIC_2;
+    const gsl_rng_type     *T = NULL;
+    gsl_rng                *r2 = NULL;
 
-    weights = calloc(length, sizeof(double));
+    T = gsl_rng_ranlxs2;
+    r2 = gsl_rng_alloc(T);
+
+    weights = calloc(length, sizeof(unsigned int));
+    p = calloc(length, sizeof(double));
     jackarray = calloc(length, sizeof(double));
 
     for (i = 0; i < length; ++i)
-        weights[i] = 1.0;
+        p[i] = 1.0 / length;
 
     param1_2 = param2_2 = logL_2 = AIC_2 = BIC_2 = 0.0;
     for (i = 0; i < dfparams->bootstrap; ++i)
     {
         if (i > 0)
-            multinomial_eqdev(length, (1.0 / length), weights, length);
+            //multinomial_eqdev(length, (1.0 / length), weights, length);
+            gsl_ran_multinomial (r2, length, length, p, weights);
 
         j = k = 0;
         while(j < length && k < length)
@@ -906,6 +1014,8 @@ BootFit(DistStats **diststats, int distindex, double *array, int length, DFParam
 
     free(weights);
     free(jackarray);
+    free(p);
+    gsl_rng_free(r2);
 }
 
 
@@ -1039,33 +1149,53 @@ MultiDistFit(DistFit *distfit_func, char dist_name[][32],
 void
 CalcAkaike(DistStats **diststats, int distnum)
 {
-    double         wtsum;
+    double         wtsum, largest;
     int            i;
 
+    largest = -DBL_MAX;
+    for(i = 0; i < distnum; ++i)
+    {
+        if (TestDistVsData(i) == 0)
+            continue;
+
+        if (largest < diststats[i]->AIC)
+            largest = diststats[i]->AIC;
+    }
+
     wtsum = 0.0;
     for(i = 0; i < distnum; ++i)
     {
         if (TestDistVsData(i) == 0)
             continue;
 
+/* 
         if(diststats[i]->AIC == -DBL_MAX ||
            diststats[i]->chisq < 0.0)
             continue;
+ */
 
-        diststats[i]->akaikewt = exp(diststats[i]->AIC - diststats[0]->AIC);
+        diststats[i]->akaikewt = exp(diststats[i]->AIC - largest);
+        
+        //printf("\nweight[%d]:%e %e %e", i, diststats[i]->akaikewt, largest, diststats[i]->AIC);
+        
+        if (!isfinite(diststats[i]->akaikewt))
+            diststats[i]->akaikewt = 0.0;
+        
         wtsum += diststats[i]->akaikewt;
     }
 
     for(i = 0; i < distnum; ++i)
     {
+ 
         if (TestDistVsData(i) == 0)
             continue;
+/*
+        if(diststats[i]->AIC == -DBL_MAX || diststats[i]->chisq < 0.0)
+            diststats[i]->bayesprob = 0.0;
+        else
+ */
 
-        if(diststats[i]->AIC == -DBL_MAX ||
-           diststats[i]->chisq < 0.0)
-            continue;
-
-        diststats[i]->bayesprob = diststats[i]->akaikewt / wtsum;
+            diststats[i]->bayesprob = diststats[i]->akaikewt / wtsum;
     }
 }
 
@@ -1229,8 +1359,8 @@ Usage(void)
     fprintf(stderr, "     (4)  Cauchy,       (5)  Uniform,   (6)  Weibull,  (7)  Gamma, \n");
     fprintf(stderr, "     (8)  ChiSqrGen,    (9)  Lognormal, (10) InvGamma, (11) InvGauss, \n");
     fprintf(stderr, "     (12) RecInvGauss,  (13) Pareto,    (14) Exp,      (15) InvChiSqr, \n");
-    fprintf(stderr, "     (16) ChiSqr,       (17) Chi,       (18) Maxwell,  (19) Beta, \n"); 
-    fprintf(stderr, "     (20) BetaSymm,     (21) BetaPrime \n");
+    fprintf(stderr, "     (16) ChiSqr,       (17) Chi,       (18) Rayleigh  (19) Maxwell,  \n"); 
+    fprintf(stderr, "     (20) Beta,         (21) BetaSymm,  (22) BetaPrime \n");
     fprintf(stderr, "  -D {distribution} -- distribution to simulate, use w/ -np \n");
     fprintf(stderr, "  -m {# of mixtures} -- fit a normal mixture distribution \n");
     fprintf(stderr, "  -n {# replicates} -- number of variates to simulate \n");
