@@ -1451,6 +1451,40 @@ double
 stdnormal(void);
 
 #endif
+
+#ifndef RAYLEIGH_DIST_SEEN
+#define RAYLEIGH_DIST_SEEN
+
+#include <gsl/gsl_rng.h>
+#include <gsl/gsl_randist.h>
+
+double
+rayleigh_dev(const double a, const double b, const gsl_rng *r2);
+
+double
+rayleigh_pdf(const double x, const double a, const double b);
+
+double
+rayleigh_lnpdf(const double x, const double a, const double b);
+
+double
+rayleigh_cdf(const double x, const double a, const double b);
+
+double
+rayleigh_sdf(const double x, const double a, const double b);
+
+double
+rayleigh_int(const double x, const double y, const double a, const double b);
+
+double
+rayleigh_logL(const double a, const double b);
+
+double
+rayleigh_fit(const double *x, const int n, double *eta, double *beta, double *prob);
+
+#endif
+
+
 #ifndef UNIFORM_DIST_SEEN
 #define UNIFORM_DIST_SEEN
 
