@@ -57,108 +57,6 @@ gamma_dev(const double b, const double c, const gsl_rng *r2)
     return(gsl_ran_gamma(r2, c, b));
 }
 
-/* double */
-/* gamma_dev(const double b, const double c, const gsl_rng *r2) */
-/* { */
-/*    assume a > 0 */
-/*    int nc = floor (c); */
-/*  */
-/*    if (c == nc) */
-/*        return (b * gamma_int_dev(nc)); */
-/*    else if (nc == 0.0) */
-/*        return (b * gamma_frac_dev(c)); */
-/*    else */
-/*        return (b * (gamma_int_dev(nc) + gamma_frac_dev(c - nc))); */
-/* } */
-
-
-double
-gamma_int_dev(const unsigned int a)
-{
-    unsigned int    i;
-    double          prod;
-
-    if (a < 12)
-    {
-        prod  = 1.0;
-
-        for (i = 0; i < a; ++i)
-            prod *= genrand_real3();
-
-        /* Note: for 12 iterations we are safe against underflow, since
-           the smallest positive random number is O(2^-32). This means
-           the smallest possible product is 2^(-12*32) = 10^-116 which
-           is within the range of const double precision. */
-
-        return (-log(prod));
-    }
-    else
-    {
-        return (gamma_large_dev(a));
-    }
-}
-
-
-double
-gamma_large_dev(const double a)
-{
-    /* Works only if a > 1, and is most efficient if a is large
-
-       This algorithm, reported in Knuth, is attributed to Ahrens.
-       A faster one, we are told, can be found in: J. H. Ahrens and
-       U. Dieter, Computing 12 (1974) 223-246.  */
-
-    double          sqa, x, y, v;
-
-    sqa = sqrt((2.0 * a) - 1.0);
-
-    do
-    {
-        do
-        {
-            y = tan(MY_PI * genrand_real2());
-            x = (sqa * y) + a - 1.0;
-        }
-        while (x <= 0.0);
-
-        v = genrand_real3();
-    }
-    while (v > (1.0 + mysquare(y)) * exp((a - 1.0) * log(x / (a - 1.0)) - (sqa * y)));
-
-    return (x);
-}
-
-
-double
-gamma_frac_dev(const double a)
-{
-    /* This is exercise 16 from Knuth; see page 135, and the solution is
-       on page 551.  */
-    double          p, q, x, u, v;
-
-    p = MY_E / (a + MY_E);
-
-    do
-    {
-        u = genrand_real3();
-        v = genrand_real3();
-
-        if (u < p)
-        {
-            x = exp((1.0 / a) * log(v));
-            q = exp(-x);
-        }
-        else
-        {
-            x = 1.0 - log(v);
-            q = exp((a - 1.0) * log(x));
-        }
-    }
-    while (genrand_real3() >= q);
-
-    return (x);
-}
-
 
 double
 gamma_pdf(const double x, const double b, const double c)
