@@ -731,9 +731,12 @@ double
 ExpInvXn(const double b, const double c, const double xn1)
 {
     double          ratio = b/xn1;
+    double          result; // = gsl_sf_gamma_inc(c + 1.0, ratio) / (b * gsl_sf_gamma_inc(c, ratio));
+
+    result = (0.5 / b) + ((sqrt(ratio) * exp(-ratio)) / (b * sqrt(3.1415926535) * erfc(sqrt(ratio))));
 
     if (ratio < 100.0)
-        return(gsl_sf_gamma_inc(c + 1.0, ratio) / (b * gsl_sf_gamma_inc(c, ratio)));
+        return(result);
     else
         return(1.0/xn1 + 1.0/b);
 }
