@@ -1207,24 +1207,3 @@ student_t(double t, double df)
 {
     return(InBeta((0.5 * df), 0.5, (df / (df + mysquare(t)))));
 }
-
-
-/* returns a random variate from the standard normal */
-/* distribution. Taken from Numerical Recipes in C. */ 
-double
-stdnormal(void)
-{
-    double          fac, r, v1, v2;
- 
-    do
-    {
-            v1 = 2.0 * genrand_real2() - 1.0;
-            v2 = 2.0 * genrand_real2() - 1.0;
-            r = mysquare(v1) + mysquare(v2);
-    }
-    while (r >= 1.0);
-
-    fac = sqrt(-2.0 * log(r) / r);
-
-    return (v2 * fac);
-}
