@@ -26,17 +26,7 @@
 #ifndef MULTIVARGAMMA_SEEN
 #define MULTIVARGAMMA_SEEN
 
-
 double
-InBeta(double a, double b, double x);
-
-double
-InGamma(double a, double x);
-
-double
-InGammaQ(double a, double x);
-
-double
-InGammaP(double a, double x);
+MultivarLnGamma(const int k, const double a);
 
 #endif
