@@ -34,7 +34,6 @@
 #include "pdbMalloc.h"
 #include "pdbUtils.h"
 #include "Embed.h"
-#include "LedoitWolf.h"
 #include "CovMat.h"
 #include "MultiPose.h"
 #include "PCAstats.h"
@@ -44,9 +43,4 @@
 #include "pdbStats.h"
 
 extern int
-MultiPose(CoordsArray *baseA); /* theseus.c */
-
-#if defined(__APPLE__)
-    #include <vecLib/clapack.h>
-    #include <vecLib/cblas.h>
-#endif
+MultiPose(CdsArray *baseA); /* theseus.c */
