@@ -151,13 +151,13 @@ main(int argc, char *argv[])
 
     if (algo->convlele > 0)
     {
-        ConvertDryden(algo->infiles[0], 2, algo->iterations /* # coordinates/forms */, algo->landmarks /* # of landmarks */);
-        //ConvertLele_freeform(algo->infiles[0], 3, algo->iterations /* # coordinates/forms */, algo->landmarks /* # of landmarks */);
+        //ConvertDryden(algo->infiles[0], 2, algo->iterations /* # coordinates/forms */, algo->landmarks /* # of landmarks */);
+        ConvertLele_freeform(algo->infiles[0], 3, algo->iterations /* # coordinates/forms */, algo->landmarks /* # of landmarks */);
         PrintTheseusTag();
         exit(EXIT_SUCCESS);
     }
 
-    if (algo->random > 0) /* for benchmarking, testing ML algorithm */
+    if (/* algo->random > */ 0) /* for benchmarking, testing ML algorithm */
     {
 		gsl_rng_env_setup();
 		gsl_rng_default_seed = time(NULL);
@@ -307,6 +307,12 @@ main(int argc, char *argv[])
     baseA->pdbA = pdbA;
     pdbA->cdsA = baseA;
 
+    if (algo->scalefactor > 1.0 || algo->scalefactor < 1.0)
+    {
+        for (i = 0; i < baseA->cnum; ++i)
+            ScaleCds(baseA->cds[i], algo->scalefactor);
+    }
+
     /* CalcPreStats(baseA); */
 
     #if defined(__APPLE__)
@@ -317,8 +323,13 @@ main(int argc, char *argv[])
 
     if (algo->random == '0')
     {
+		gsl_rng_env_setup();
+		gsl_rng_default_seed = time(NULL);
+		T = gsl_rng_ranlxs2;
+		r2 = gsl_rng_alloc(T);
+
         RandRotCdsArray(baseA, r2);
-        RandTransCdsArray(baseA, 0.1, r2);
+        RandTransCdsArray(baseA, 30, r2);
         printf("    Writing CA coordinates of transformed random structures ... \n");
         fflush(NULL);
         for (i = 0; i < baseA->cnum; ++i)
@@ -555,7 +566,7 @@ main(int argc, char *argv[])
     if (mean_ip_name != NULL)
         free(mean_ip_name);
 
-    pthread_exit(NULL);
+//    pthread_exit(NULL);
 
     return (EXIT_SUCCESS);
 }
@@ -593,7 +604,7 @@ ParseCmdLine(int argc, char *argv[], CdsArray *bseA)
     }
 
     /*  */
-    while ((option = getopt(argc, argv, "a:A:b:B:cCd:D:e:EfFg:GhHi:Ij:Jk:K:lLm:M:nNo:Op:P:q:Qr:R:s:S:tT:uUvVw:WxXyYz:Z0123:4:56789")) != -1)
+    while ((option = getopt(argc, argv, "a:A:b:B:cCd:D:e:EfFg:GhHi:Ij:Jk:K:lLm:M:nNo:Op:P:q:Q:r:R:s:S:tT:uUvVw:WxXyYz:Z0123:4:56789")) != -1)
     {
         switch (option) /* See Algorithm structure in Cds.h for explanations of these flags/options */
         {
@@ -745,7 +756,7 @@ ParseCmdLine(int argc, char *argv[], CdsArray *bseA)
                 break;
             case 'j':
                 algo->landmarks = (int) strtol(optarg, NULL, 10);
-            //    break;
+                break;
             case 'J': /* very expert options help message */
                 Usage(2);
                 exit(EXIT_SUCCESS);
@@ -837,7 +848,8 @@ ParseCmdLine(int argc, char *argv[], CdsArray *bseA)
                        &algo->raxes[2]);
                 break;
             case 'Q':
-                algo->modelpca = 1;
+                //algo->modelpca = 1;
+                algo->scalefactor = (double) strtod(optarg, NULL);
                 break;
             case 'r':
                 mystrncpy(algo->rootname, optarg, FILENAME_MAX - 1);
